"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = exports.ALL_WEB_MASKS = exports.ALL_LIST_MASKS = exports.LIST = void 0;
// See: https://docs.microsoft.com/en-us/openspecs/sharepoint_protocols/ms-wssfo3/1f5e3322-920f-431c-bbc4-7f65c477e698
var LIST = {
  VIEW_LIST_ITEMS: {
    STATIC_NAME: "ViewListItems",
    VALUE: 0x0000000000000001,
    DESCRIPTION: "Allow viewing of list items in lists, documents in document libraries, and Web discussion comments."
  },
  ADD_LIST_ITEMS: {
    STATIC_NAME: "AddListItems",
    VALUE: 0x0000000000000002,
    DESCRIPTION: "Allow addition of list items to lists, documents to document libraries, and Web discussion comments."
  },
  EDIT_LIST_ITEMS: {
    STATIC_NAME: "EditListItems",
    VALUE: 0x0000000000000004,
    DESCRIPTION: "Allow editing of list items in lists, documents in document libraries, Web discussion comments, and to customize Web Part pages in document libraries."
  },
  DELETE_LIST_ITEMS: {
    STATIC_NAME: "DeleteListItems",
    VALUE: 0x0000000000000008,
    DESCRIPTION: "Allow deletion of list items from lists, documents from document libraries, and Web discussion comments."
  },
  APPROVE_ITEMS: {
    STATIC_NAME: "ApproveItems",
    VALUE: 0x0000000000000010,
    DESCRIPTION: "Allow approval of minor versions of a list item or document."
  },
  OPEN_ITEMS: {
    STATIC_NAME: "OpenItems",
    VALUE: 0x0000000000000020,
    DESCRIPTION: "Allow viewing the source of documents with server-side file handlers."
  },
  VIEW_VERSIONS: {
    STATIC_NAME: "ViewVersions",
    VALUE: 0x0000000000000040,
    DESCRIPTION: "Allow viewing of past versions of a list item or document."
  },
  DELETE_VERSIONS: {
    STATIC_NAME: "DeleteVersions",
    VALUE: 0x0000000000000080,
    DESCRIPTION: "Allow deletion of past versions of a list item or document."
  },
  CANCEL_CHECKOUT: {
    STATIC_NAME: "CancelCheckout",
    VALUE: 0x0000000000000100,
    DESCRIPTION: "Allow discard or check in of a document that is checked out to another user."
  },
  MANAGE_PERSONAL_VIEWS: {
    STATIC_NAME: "ManagePersonalViews",
    VALUE: 0x0000000000000200,
    DESCRIPTION: "Allow creation, change, and deletion of personal views of lists."
  },
  MANAGE_LISTS: {
    STATIC_NAME: "ManageLists",
    VALUE: 0x0000000000000800,
    DESCRIPTION: "Allow creation and deletion of lists, addition or removal of fields to the schema of a list, and addition or removal of personal views of a list."
  },
  VIEW_FORM_PAGES: {
    STATIC_NAME: "ViewFormPages",
    VALUE: 0x0000000000001000,
    DESCRIPTION: "Allow viewing of forms, views, and application pages, and enumerate lists."
  },
  ANONYMOUS_SEARCH_ACCESS_LIST: {
    STATIC_NAME: "AnonymousSearchAccessList",
    VALUE: 0x0000000000002000,
    DESCRIPTION: "Allow anonymous users to retrieve content of a list or document library through SharePoint search. The list permissions in the site (2) do not change."
  }
};
exports.LIST = LIST;
var WEB = {
  OPEN: {
    STATIC_NAME: "Open",
    VALUE: 0x0000000000010000,
    DESCRIPTION: "Allow access to the items contained within a site (2), list, or folder."
  },
  VIEW_PAGES: {
    STATIC_NAME: "ViewPages",
    VALUE: 0x0000000000020000,
    DESCRIPTION: "Allow viewing of pages in a site (2)."
  },
  ADD_AND_CUSTOMISE_PAGES: {
    STATIC_NAME: "AddAndCustomizePages",
    VALUE: 0x0000000000040000,
    DESCRIPTION: "Allow addition, modification, or deletion of HTML pages or Web Part pages, and editing of the site (2) using a compatible editor."
  },
  APPLY_THEME_AND_BORDER: {
    STATIC_NAME: "ApplyThemeAndBorder",
    VALUE: 0x0000000000080000,
    DESCRIPTION: "Allow application of a theme or borders to the entire site (2)."
  },
  APPLY_STYLE_SHEETS: {
    STATIC_NAME: "ApplyStyleSheets",
    VALUE: 0x0000000000100000,
    DESCRIPTION: "Allow application of a style sheet (.css file) to the site (2)."
  },
  VIEW_USAGE_AND_DATA: {
    STATIC_NAME: "ViewUsageData",
    VALUE: 0x0000000000200000,
    DESCRIPTION: "Allow viewing of reports on site usage."
  },
  CREATE_SSC_SITE: {
    STATIC_NAME: "CreateSSCSite",
    VALUE: 0x0000000000400000,
    DESCRIPTION: "Allow creation of a site (2) using Self-Service Site Creation, an implementation-specific capability."
  },
  MANAGE_SUB_WEBS: {
    STATIC_NAME: "ManageSubwebs",
    VALUE: 0x0000000000800000,
    DESCRIPTION: "Allow creation of a subsite within the site (2) or site collection."
  },
  CREATE_GROUPS: {
    STATIC_NAME: "CreateGroups",
    VALUE: 0x0000000001000000,
    DESCRIPTION: "Allow creation of a group (2) of users that can be used anywhere within the site collection."
  },
  MANAGE_PERMISSIONS: {
    STATIC_NAME: "ManagePermissions",
    VALUE: 0x0000000002000000,
    DESCRIPTION: "Allow creation and modification of permission levels on the site (2) and assigning permissions to users and site groups."
  },
  BROWSE_DIRECTORIES: {
    STATIC_NAME: "BrowseDirectories",
    VALUE: 0x0000000004000000,
    DESCRIPTION: "Allow enumeration of documents and folders in a site (2) using [MS-FPSE] and WebDAV interfaces."
  },
  BROWSE_USER_INFO: {
    STATIC_NAME: "BrowseUserInfo",
    VALUE: 0x0000000008000000,
    DESCRIPTION: "Allow viewing the information about all users of the site (2)."
  },
  ADD_DEL_PRIVATE_WEB_PARTS: {
    STATIC_NAME: "AddDelPrivateWebParts",
    VALUE: 0x0000000010000000,
    DESCRIPTION: "Allow addition or removal of personal Web Parts on a Web Part page."
  },
  UPDATE_PERSONAL_WEB_PARTS: {
    STATIC_NAME: "UpdatePersonalWebParts",
    VALUE: 0x0000000020000000,
    DESCRIPTION: "Allow updating of Web Parts to display personalized information."
  },
  MANAGE_WEB: {
    STATIC_NAME: "ManageWeb",
    VALUE: 0x0000000040000000,
    DESCRIPTION: "Allow all administration tasks for the site (2) as well as manage content."
  },
  ANONYMOUS_SEARCH_ACCESS_WEB_LISTS: {
    STATIC_NAME: "AnonymousSearchAccessWebLists",
    VALUE: 0x0000000080000000,
    DESCRIPTION: "Allow content of lists and document libraries in the site (2) to be retrievable for anonymous users through SharePoint search if the list or document library has AnonymousSearchAccessList set."
  },
  USE_CLIENT_INTEGRATION: {
    STATIC_NAME: "UseClientIntegration",
    VALUE: 0x0000001000000000,
    DESCRIPTION: "Allow use of features that launch client applications; otherwise, users can only work on documents on their local machines and upload changes to the front-end Web server."
  },
  USE_REMOTE_APIS: {
    STATIC_NAME: "UseRemoteAPIs",
    VALUE: 0x0000002000000000,
    DESCRIPTION: "Allow use of SOAP, WebDAV, or [MS-FPSE] to access the site (2)."
  },
  MANAGE_ALERTS: {
    STATIC_NAME: "ManageAlerts",
    VALUE: 0x0000004000000000,
    DESCRIPTION: "Allow management of alerts for all users of the site (2)."
  },
  CREATE_ALERTS: {
    STATIC_NAME: "CreateAlerts",
    VALUE: 0x0000008000000000,
    DESCRIPTION: "Allow creation of e-mail alerts."
  },
  EDIT_MY_USER_INFO: {
    STATIC_NAME: "EditMyUserInfo",
    VALUE: 0x0000010000000000,
    DESCRIPTION: "Allow users to change their own user information, such as adding a picture."
  }
};
var ALL_LIST_MASKS = Object.keys(LIST).map(function (key) {
  return LIST[key];
});
exports.ALL_LIST_MASKS = ALL_LIST_MASKS;
var ALL_WEB_MASKS = Object.keys(WEB).map(function (key) {
  return WEB[key];
});
exports.ALL_WEB_MASKS = ALL_WEB_MASKS;
var MASKS = {
  LIST: LIST,
  WEB: WEB
};
var _default = MASKS;
exports["default"] = _default;