"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

/**
 * @name copyIntoItems
 * @description Copies a document represented by a Byte array to one or more locations on a server.
 * @param {Object} payload
 * @param {String} [payload.sourceUrl=" "] A String that contains the absolute source URL of the document to be copied.
 * @param {Array|String} payload.destinationUrls - A String or an array of Strings that contain one or more absolute URLs specifying the destination location or locations of the copied document.
 * @param {String} payload.stream - The base 64 data string.
 * @param {String} [payload.webURL=""] - The web site url.
 * @param {Boolean} [payload.async=true] If false, the request will be synchronous.
 * @returns {Promise} Returns a Promise with the response as XML.
 */
var copyIntoItems = function copyIntoItems(_ref) {
  var _ref$async = _ref.async,
      async = _ref$async === void 0 ? false : _ref$async,
      destinationUrls = _ref.destinationUrls,
      _ref$sourceUrl = _ref.sourceUrl,
      sourceUrl = _ref$sourceUrl === void 0 ? " " : _ref$sourceUrl,
      stream = _ref.stream,
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? window.$().SPServices.defaults.webURL : _ref$webURL;
  return new Promise(function (resolve, reject) {
    {
      var DestinationUrls = Array.isArray(destinationUrls) ? destinationUrls : [destinationUrls];
      window.$().SPServices({
        operation: "CopyIntoItems",
        webURL: webURL,
        // The SourceUrl is required and cannot be blank. Adding a space forces the string to be truly and SharePoint accepts the request. If blank the request fails.
        SourceUrl: sourceUrl,
        DestinationUrls: DestinationUrls,
        Stream: stream,
        async: async,
        completefunc: function completefunc(xData, status) {
          if (status === "success") {
            resolve(xData.responseXML);
          } else {
            reject(xData.responseXML);
          }
        }
      });
    }
  });
};

var _default = copyIntoItems;
exports["default"] = _default;