"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getListsError = _interopRequireDefault(require("../../utils/errors/getListsError"));

var _getListsOptions2 = _interopRequireDefault(require("../../utils/options/getListsOptions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name addAttachment
 * @description Adds an attachment to the specified list item in the specified list.
 * @required listName, listItemID, fileName, attachment
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {string} options.listItemID - The list item ID.
 * - Required: Yes
 * @param {string} options.fileName - The filename that will be created.
 * - Required: Yes
 * @param {string} options.attachment - The base 64 data string.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
var addAttachment = function addAttachment(options) {
  return new Promise(function (resolve, reject) {
    var _getListsOptions = (0, _getListsOptions2["default"])(options),
        webURL = _getListsOptions.webURL,
        listName = _getListsOptions.listName,
        async = _getListsOptions.async,
        listItemID = _getListsOptions.listItemID,
        fileName = _getListsOptions.fileName,
        attachment = _getListsOptions.attachment;

    $().SPServices({
      operation: "AddAttachment",
      webURL: webURL,
      listName: listName,
      async: async,
      listItemID: listItemID,
      fileName: fileName,
      attachment: attachment,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject((0, _getListsError["default"])(xData));
        }
      }
    });
  });
};

var _default = addAttachment;
exports["default"] = _default;