"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @name addList
 * @description Creates a list in the current site based on the specified name, description, and list template ID.
 * @param {Object} payload The configuration payload object
 * @param {String} payload.listName The list static name
 * @param {Number|String} payload.templateID The list template ID
 * @param {String} payload.description A short description of the list
 * @param {String} [payload.webURL=window.$().SPServices.defaults.webURL] The web site url
 * @param {Boolean} [payload.parse=false] If true, the response is returned as an object
 * @returns {Promise<Object>} Returns an XML object or if parsed, a list object
 */
var addList = function addList() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async,
      _ref$description = _ref.description,
      description = _ref$description === void 0 ? "" : _ref$description,
      listName = _ref.listName,
      _ref$templateID = _ref.templateID,
      templateID = _ref$templateID === void 0 ? 100 : _ref$templateID,
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? window.$().SPServices.defaults.webURL : _ref$webURL,
      _ref$parse = _ref.parse,
      parse = _ref$parse === void 0 ? false : _ref$parse;

  return new Promise(function (resolve, reject) {
    // if listName is not defined.
    if (!listName) {
      // Reject with error and end function
      return reject(new Error("listName not defined. Unable to create list."));
    }

    $().SPServices({
      operation: "AddList",
      async: async,
      description: description,
      listName: listName,
      templateID: templateID,
      webURL: webURL,
      completefunc: function completefunc(xData, status) {
        // Get XML Response
        var xml = xData.responseXML; // Check for error text

        var errorText = ((xml.querySelector("errorstring") || {}).textContent || "").trim(); // If error is found

        if (errorText || status === "error") {
          // Create error object
          var error = new Error(errorText || "Unable to create the list.");
          error.status = xData.status;
          error.statusText = xData.statusText; // Reject with error

          return reject(error);
        } // Get xml response


        var response = xml.querySelector("List"); // If parse is false, resolve response

        if (!parse) return resolve(response); // Create list object

        var list = _toConsumableArray(response.attributes).reduce(function (object, _ref2) {
          var name = _ref2.name,
              value = _ref2.value;
          object[name] = value || "";
          return object;
        }, {}); // Get fields


        list.fields = _toConsumableArray(response.querySelectorAll("Field")).map(function (field) {
          return _toConsumableArray(field.attributes).reduce(function (object, _ref3) {
            var name = _ref3.name,
                value = _ref3.value;
            object[name] = value || "";
            return object;
          }, {});
        }); // Get regional settings

        list.regionalSettings = _toConsumableArray(response.querySelector("RegionalSettings").childNodes).reduce(function (object, _ref4) {
          var nodeName = _ref4.nodeName,
              textContent = _ref4.textContent;
          object[nodeName] = textContent || "";
          return object;
        }, {}); // Get server settings

        list.serverSettings = _toConsumableArray(response.querySelector("ServerSettings").childNodes).reduce(function (object, _ref5) {
          var nodeName = _ref5.nodeName,
              textContent = _ref5.textContent;
          object[nodeName] = textContent || "";
          return object;
        }, {}); // Resolve parsed list

        return resolve(list);
      }
    });
  });
};

var _default = addList;
exports["default"] = _default;