"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getListsError = _interopRequireDefault(require("../../utils/errors/getListsError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name deleteAttachment
 * @description Adds an attachment to the specified list item in the specified list.
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * @param {string} options.listItemID - The list item ID.
 * @param {string} options.url - A string that contains the absolute URL for the attachment
 * @param {string} [options.webURL=""] - The web site url.
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * @returns {Promise} Returns a Promise XML result.
 * @example
 * deleteAttachment({
 * webURL: "http://objectpoint/sites/development",
 *  listName: "Delete Attachment",
 *  listItemID: 1,
 *  url:
 *    "http://objectpoint/sites/development/Lists/DeleteAttachment/Attachments/1/report.docx"
 * }).then(res => {
 *  console.info("res", res);
 * });
 */
var deleteAttachment = function deleteAttachment(_ref) {
  var _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async,
      listItemID = _ref.listItemID,
      listName = _ref.listName,
      url = _ref.url,
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? window.$().SPServices.defaults.webURL : _ref$webURL;
  return new Promise(function (resolve, reject) {
    $().SPServices({
      operation: "DeleteAttachment",
      webURL: webURL,
      listName: listName,
      async: async,
      listItemID: listItemID,
      url: url,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject((0, _getListsError["default"])(xData));
        }
      }
    });
  });
};

var _default = deleteAttachment;
exports["default"] = _default;