"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getListsError = _interopRequireDefault(require("../../utils/errors/getListsError"));

var _getListsOptions2 = _interopRequireDefault(require("../../utils/options/getListsOptions"));

var _parseList = _interopRequireDefault(require("../../utils/lists/parseList"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name getList
 * @description Get a schema for the specified list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * @param {string} [options.webURL=window.$().SPServices.defaults.webURL] - The web site url
 * @param {boolean} [options.parse=false] - XML will be parsed with items return
 * @param {boolean} [options.readOnlyColumns=null] - Read only columns will be returned
 * @param {boolean} [options.viewColumns=null] - Only columns that are selectable in views will be returned
 * @param {boolean} [options.hiddenColumns=null] - Hidden columns will be returned
 * @param {boolean} [options.customColumns=null] - Custom columns will be returned
 * @param {boolean} [options.columnAttributes=[]] - Array of column attribute names will return only those attributes
 * @param {boolean} [options.async=true] - Synchronisation Type
 * @returns {Promise} Returns a Promise XML result.
 */
var getList = function getList(options) {
  return new Promise(function (resolve, reject) {
    var _getListsOptions = (0, _getListsOptions2["default"])(options),
        webURL = _getListsOptions.webURL,
        listName = _getListsOptions.listName,
        parse = _getListsOptions.parse,
        async = _getListsOptions.async,
        readOnlyColumns = _getListsOptions.readOnlyColumns,
        hiddenColumns = _getListsOptions.hiddenColumns,
        customColumns = _getListsOptions.customColumns,
        columnAttributes = _getListsOptions.columnAttributes,
        viewColumns = _getListsOptions.viewColumns;

    $().SPServices({
      operation: "GetList",
      webURL: webURL,
      listName: listName,
      async: async,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          if (parse) {
            (0, _parseList["default"])({
              xml: xData.responseXML,
              readOnlyColumns: readOnlyColumns,
              hiddenColumns: hiddenColumns,
              customColumns: customColumns,
              columnAttributes: columnAttributes,
              viewColumns: viewColumns
            }).then(function (list) {
              resolve(list);
            });
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject((0, _getListsError["default"])(xData));
        }
      }
    });
  });
};

var _default = getList;
exports["default"] = _default;