"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getListsError = _interopRequireDefault(require("../../utils/errors/getListsError"));

var _getListsOptions2 = _interopRequireDefault(require("../../utils/options/getListsOptions"));

var _Response = _interopRequireDefault(require("../../classes/Response"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name getListCollection
 * @required null
 * @description Get the names and GUIDs for all lists in the site.
 * @param {object} options
 * @param {string} [options.webURL=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.parse=false] - XML will be parsed with items return
 * - Required: No
 * - Default: false
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
var getListCollection = function getListCollection(options) {
  return new Promise(function (resolve, reject) {
    var _getListsOptions = (0, _getListsOptions2["default"])(options),
        webURL = _getListsOptions.webURL,
        async = _getListsOptions.async,
        parse = _getListsOptions.parse;

    $().SPServices({
      operation: "GetListCollection",
      webURL: webURL,
      async: async,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          if (parse) {
            var lists = [];
            $(xData.responseXML).SPFilterNode("List").each(function () {
              lists.push(new _Response["default"]({
                xml: this
              }));
            });
            resolve(lists);
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject((0, _getListsError["default"])(xData));
        }
      }
    });
  });
};

var _default = getListCollection;
exports["default"] = _default;