"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getList = _interopRequireDefault(require("./getList"));

var _escapeHtml = _interopRequireDefault(require("../../utils/general/escapeHtml"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * @name updateList
 * @description Creates a list in the current site based on the specified name, description, and list template ID.
 * @param {Object} payload The configuration payload object
 * @param {String} payload.listName The list static name
 * @param {String} [payload.webURL=window.$().SPServices.defaults.webURL] The web site url
 * @param {Boolean} [payload.parse=false] If true, the response is returned as an object
 * @param {Object} [payload.listProperties=null] The list static name
 * @param {String} [payload.listProperties.description] A string that contains the description for the list.
 * @param {String} [payload.listProperties.direction] A string that contains LTR if the reading order is left-to-right, RTL if it is right-to-left, or None.
 * @param {Boolean} [payload.listProperties.enableAttachments] true to enable attachments to items in the list. Does not apply to document libraries.
 * @param {Boolean} [payload.listProperties.enableVersioning] true to enable versioning for the list.
 * @param {Boolean} [payload.listProperties.enforceDataValidation] ?.
 * @param {Boolean} [payload.listProperties.hidden] true to hide the list so that it does not appear on the Documents and Lists page, Quick Launch bar, Modify Site Content page, or Add Column page as an option for lookup fields.
 * @param {Boolean} [payload.listProperties.ordered] true to specify that the option to allow users to reorder items in the list is available on the Edit View page for the list.
 * @param {Boolean} [payload.listProperties.preserveEmptyValues] ?.
 * @param {Boolean} [payload.listProperties.showUser] ?.
 * @param {Boolean} [payload.listProperties.strictTypeCoercion] ?.
 * @param {Boolean} [payload.listProperties.enableMinorVersion] true enables minor versioning (only avaialble for certain list types).
 * @param {Boolean} [payload.listProperties.requireCheckout] true enables checkout for document libraries only.
 * @param {Boolean} [payload.listProperties.allowMultiResponses] true enables multiple responses for survey lists only.
 * @param {String} [payload.listProperties.Title] A string that contains the title of the list.
 * @param {Object[]} [payload.newFields] An array containing field objects to be created
 * @param {String} payload.newFields[].name The field static name. This is required to locate the field.
 * @param {String} payload.newFields[].type The field type
 * @param {Boolean} [payload.newFields[].displayName] The field display name.
 * @param {Boolean} [payload.newFields[].enforceUniqueValues] If true, unique values are enforced (column must be indexed first)
 * @param {String[]} [payload.newFields[].choices] An array of choices (For choice field types only)
 * @param {Boolean} [payload.newFields[].indexed] If true, the column will be indexed
 * @param {Boolean} [payload.newFields[].readOnly] If true, the column will be read only
 * @param {Boolean} [payload.newFields[].required] If true, the column will be required
 * @param {Number} [payload.newFields[].max] The maximum value for number fields only
 * @param {Number} [payload.newFields[].min] The minimum value for number fields only
 * @param {Number} [payload.newFields[].maxLength] The maximum length for text fields only
 * @param {Object[]} [payload.updateFields] An array containing field objects to be updated
 * @param {String} payload.updateFields[].name The field static name. This is required to locate the field.
 * @param {String} payload.updateFields[].type The field type
 * @param {Boolean} [payload.updateFields[].displayName] The field display name.
 * @param {Boolean} [payload.updateFields[].enforceUniqueValues] If true, unique values are enforced (column must be indexed first)
 * @param {String[]} [payload.updateFields[].choices] An array of choices (For choice field types only)
 * @param {Boolean} [payload.updateFields[].indexed] If true, the column will be indexed
 * @param {Boolean} [payload.updateFields[].readOnly] If true, the column will be read only
 * @param {Boolean} [payload.updateFields[].required] If true, the column will be required
 * @param {Number} [payload.updateFields[].max] The maximum value for number fields only
 * @param {Number} [payload.updateFields[].min] The minimum value for number fields only
 * @param {Number} [payload.updateFields[].maxLength] The maximum length for text fields only
 * @param {Object[]} [payload.deleteFields] An array containing field objects to be deleted
 * @param {String} payload.deleteFields[].name The field static name. This is required to locate the field.
 * @returns {Promise<Object>} Returns an XML object or if parsed, a list object
 */
var updateList = function updateList() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async,
      listName = _ref.listName,
      _ref$listProperties = _ref.listProperties,
      listProperties = _ref$listProperties === void 0 ? null : _ref$listProperties,
      _ref$newFields = _ref.newFields,
      newFields = _ref$newFields === void 0 ? [] : _ref$newFields,
      _ref$updateFields = _ref.updateFields,
      updateFields = _ref$updateFields === void 0 ? [] : _ref$updateFields,
      _ref$deleteFields = _ref.deleteFields,
      deleteFields = _ref$deleteFields === void 0 ? [] : _ref$deleteFields,
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? window.$().SPServices.defaults.webURL : _ref$webURL,
      _ref$parse = _ref.parse,
      parse = _ref$parse === void 0 ? false : _ref$parse;

  return new Promise(function (resolve, reject) {
    // Allowed keys for fields
    var allowedKeys = ["CHOICES", "DISPLAYNAME", "ENFORCEUNIQUEVALUES", "HIDDEN", "INDEXED", "MAX", "MAXLENGTH", "MIN", "NAME", "READONLY", "REQUIRED", "TYPE"]; // if listName is not defined.

    if (!listName) {
      // Reject with error and end function
      return reject(new Error("listName not defined. Unable to update the list."));
    } // Create the request payload


    var payload = {
      operation: "UpdateList",
      async: async,
      listName: listName,
      webURL: webURL
    }; // If list listProperties are defined

    if (listProperties) {
      // Add listProperties to the payload as an xml string
      payload.listProperties = "<List " + Object.keys(listProperties).map(function (key) {
        // Get value
        var value = listProperties[key]; // Get attribute name

        var name = key[0].toUpperCase() + key.slice(1); // If boolean, convert to string

        if (typeof value === "boolean") {
          value = value ? "TRUE" : "FALSE";
        } // Return string


        return "".concat(name, "=\"").concat(value, "\"");
      }).join(" ") + " />";
    } // Create Methods


    if (newFields.length > 0) {
      payload.newFields = createFieldMethods(newFields);
    }

    if (updateFields.length > 0) {
      payload.updateFields = createFieldMethods(updateFields);
    }

    if (deleteFields.length > 0) {
      payload.deleteFields = createFieldMethods(deleteFields);
    } // Send the request


    $().SPServices(_objectSpread(_objectSpread({}, payload), {}, {
      completefunc: function completefunc(xData, status) {
        // Get XML Response
        var xml = xData.responseXML; // Check for error text

        var errorText = ((xml.querySelector("errorstring") || xml.querySelector("ErrorText") || {}).textContent || "").trim(); // Get the new list name (if being updated in list properties)

        var newListName = listProperties ? listProperties.title || listProperties.Title || "" : ""; // If error is found

        if (errorText || status === "error") {
          // If the list is being update an error is always thrown (SharePoint bug)
          if (newListName) {
            // To get a valid response, get the list data, by the new list name.
            return (0, _getList["default"])({
              webURL: webURL,
              listName: newListName,
              parse: parse
            }).then(function (res) {
              return resolve(res);
            });
          } else {
            // Create error object
            var error = new Error(errorText || "Unable to update list.");
            error.status = xData.status;
            error.statusText = xData.statusText; // Reject with error

            return reject(error);
          }
        } // Query the list to get all new properties and fields


        (0, _getList["default"])({
          webURL: webURL,
          listName: listName,
          parse: parse
        }).then(function (res) {
          // Return the resolved promise and response
          return resolve(res);
        });
      }
    }));
    /**
     * @name createFieldMethods
     * @description Creates field methods from an array of field objects
     * @param {Object[]} fields
     * @returns {String} Returns a XML string.
     */

    function createFieldMethods(fields) {
      return "<Fields>\n      ".concat(fields.map(function (field, index) {
        // Open method tag and assign ID
        var method = "<Method ID=\"".concat(index + 1, "\">"); // If the field is already a string

        if (typeof field === "string") {
          // Update the method
          method += field;
        } else {
          // Open field
          method += "<Field"; // Iterate through all keys in field

          for (var key in field) {
            // Uppercase KEY
            var KEY = key.toUpperCase(); // If key is not equal to choices

            if (allowedKeys.includes(KEY) && KEY !== "CHOICES") {
              // Convert key to start with uppercase
              var name = key[0].toUpperCase() + key.slice(1); // Get value

              var value = field[key]; // If boolean, convert to string

              if (typeof value === "boolean") {
                value = value ? "TRUE" : "FALSE";
              } // Add to method


              method += " ".concat(name, "=\"").concat(value, "\"");
            }
          } // Close opening field tag


          method += ">"; // Get choices

          var choices = field.choices || field.Choices || field.CHOICES; // If choices is defined

          if (choices) {
            // Update choices in method
            method += "<CHOICES>\n              ".concat(choices.map(function (choice) {
              return "<CHOICE>".concat((0, _escapeHtml["default"])(choice), "</CHOICE>");
            }).join(""), "\n              </CHOICES>");
          } // Close the field tag


          method += "</Field>";
        } // Close the method tag


        method += "</Method>"; // Return the method

        return method;
      }).join(""), "\n      </Fields>");
    }
  });
};

var _default = updateList;
exports["default"] = _default;