"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr && (typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]); if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/**
 * @name updateListItems
 * @description Adds, deletes, or updates the specified items in a list on the current site..
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * @param {array} options.methods - An array of objects containing {Cmd: "New|Update|Delete", valuepairs and ID}.
 * @param {string} [options.webURL=""] - The web site url
 * @param {boolean} [options.async=true] - Synchronisation Type
 * @param {boolean} [options.parse=false] - XML will be parsed with items return
 * @param {number} [options.batchSize=400] - The batch size. A value of 0 or null will allow an infinite batch size.
 * @param {function} [options.getBatchData] - A callback function is called when batches are ready to be sent to the server
 * @returns {Promise} Returns a Promise XML result.
 * @example
 * updateListItems({
 *  listName: "Announcements",
 *  methods: [
 *    {
 *     cmd: "New",
 *     valuepairs: [
 *      // StaticName, Value
 *      ["Title", "My App"],
 *      ["Name", "Ross"]]
 *    },
 *    {
 *      cmd: "Update",
 *      ID: 5,
 *      valuepairs: [["Title", "My App"], ["Name", "Ross"]]
 *    },
 *    {
 *     cmd: "Delete",
 *     ID: 23,
 *    }
 *  ]
 * });
 */
var updateListItems = function updateListItems() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      listName = _ref.listName,
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? "" : _ref$webURL,
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async,
      _ref$parse = _ref.parse,
      parse = _ref$parse === void 0 ? false : _ref$parse,
      _ref$methods = _ref.methods,
      methods = _ref$methods === void 0 ? [] : _ref$methods,
      _ref$batchSize = _ref.batchSize,
      batchSize = _ref$batchSize === void 0 ? 400 : _ref$batchSize,
      _ref$getBatchData = _ref.getBatchData,
      getBatchData = _ref$getBatchData === void 0 ? null : _ref$getBatchData;

  return new Promise(function (resolve, reject) {
    // Validate request
    if (methods.length === 0 || !methods[0].cmd) {
      reject("Invalid Methods. Unable to update items: ", methods);
    } // Create batches array literal
    // * Note batching is used when updating large lists to reduce risk of server timeouts


    var batches = [[]]; // Create counters

    var itemsToUpdate = methods.length;
    var index = 1;
    var batchIndex = 0;
    var errors = 0;
    var success = 0; // Iterate through methods and push to batches

    methods.forEach(function (method) {
      // Get Values
      var cmd = method.cmd;
      var ID = method.ID;
      var valuepairs = method.valuepairs; // Open method tag

      var str = "<Method ID='".concat(index, "' Cmd='").concat(cmd, "'>"); // If update or delete and ID is defined, add Field ID

      if (cmd !== "New" && ID) str += "<Field Name='ID'>".concat(ID, "</Field>"); // Add valuepairs. Delete requires the FileRef

      if (valuepairs.length > 0) {
        str += valuepairs.map(function (_ref2) {
          var _ref3 = _slicedToArray(_ref2, 2),
              name = _ref3[0],
              value = _ref3[1];

          return "<Field Name='".concat(name, "'>").concat(value, "</Field>");
        }).join("");
      } // Close method tag


      str += "</Method>"; // Push string (method) to batch

      batches[batchIndex].push(str); // If batchSize is reached

      if (batchSize > 0 && index >= batchSize) {
        // Reset counters and create new batch
        index = 1;
        batchIndex += 1;
        batches.push([]);
      } else {
        // Increase index
        index += 1;
      }
    }); // If callback is defined

    if (getBatchData) {
      getBatchData({
        batchesProcessed: 0,
        batchesTotal: batches.length,
        batchSize: batchSize,
        itemsToUpdate: itemsToUpdate,
        errors: errors,
        success: success,
        results: {
          success: [],
          errors: []
        }
      });
    } // Array literal to store all API responses


    var response = []; // Clone batches to iterate

    var array = [].concat(batches); // Aync loop

    (function loop() {
      var i = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

      // If array is empty
      if (!array || array.length === 0) {
        // Flatten array and resolve
        resolve([].concat.apply([], response)); // End function

        return;
      } // Get first array item


      var batch = array.shift(); // Send web request

      $().SPServices({
        operation: "UpdateListItems",
        webURL: webURL,
        async: async,
        listName: listName,
        updates: "<Batch OnError='Continue'>".concat(batch, "</Batch>"),
        completefunc: function completefunc(xData, status) {
          // If server error
          if (status === "error") {
            errors += batch.length;
            console.error("Error processing batch updates: ", xData.responseXML, "batch", batch);
          } // Array literal to store parsed results


          var results = {
            errors: [],
            success: []
          }; // If parse

          if (parse && status !== "parsererror" && xData.responseXML) {
            _toConsumableArray(xData.responseXML.getElementsByTagName("Result")).forEach(function (result) {
              // Get the method ID
              var methodID = result.getAttribute("ID"); // Get row

              var row = result.querySelector("row"); // Create item object literal

              var item = {}; // If row is truthy

              if (row) {
                // Increase success count
                success += 1; // Create item props

                item = _toConsumableArray(row.attributes).reduce(function (object, node) {
                  var name = node.name.split("ows_")[1];

                  if (name) {
                    object[name] = node.value;
                  }

                  return object;
                }, {});
                item.status = "success";
              } // Get Error Text (If found, an error occured)


              var errorText = _toConsumableArray(result.getElementsByTagName("ErrorText"))[0]; // If an error is found, add error data to item object


              if (errorText) {
                // Get Error Code
                var code = _toConsumableArray(result.getElementsByTagName("ErrorCode"))[0]; // Increase erorr count


                errors += 1; // Create error props

                item = _objectSpread(_objectSpread({}, item), {}, {
                  code: (code || {}).textContent,
                  message: (errorText || {}).textContent,
                  status: "error",
                  methodID: methodID
                });
              }

              if (item.status === "error") {
                results.errors.push(item);
              } else {
                results.success.push(item);
              }
            }); // If callback is defined


            if (getBatchData) {
              getBatchData({
                batchesProcessed: i + 1,
                batchesTotal: batches.length,
                batchSize: batchSize,
                itemsToUpdate: itemsToUpdate,
                success: success,
                errors: errors,
                results: results
              });
            } // Resolve item


            response.push(results); // Loop

            loop(i += 1);
          } else {
            // If callback is defined
            if (getBatchData) {
              getBatchData({
                batchesProcessed: i + 1,
                batchesTotal: batches.length,
                batchSize: batchSize,
                itemsToUpdate: itemsToUpdate,
                success: success,
                errors: errors,
                results: results
              });
            } // Resolve xml


            response.push(xData.responseXML); // Loop

            loop(i += 1);
          }
        }
      });
    })();
  });
};

var _default = updateListItems;
exports["default"] = _default;