"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

// External
var _window = window,
    $ = _window.$;
/**
 * @name resolvePrincipals
 * @description esolves an e-mail address or other form of user identification (ID) into a PrincipalInfo object.
 * @param {Object} object
 * @param {String|Array<String>} principalKeys A string or an array of logon names of the principal
 * @param {String} [principalType="User"] The Principal type must be "User" or "SharePointGroup".
 * @param {String} [webURL=window.$().SPServices.defaults.webURL] The relative webURL
 * @param {Boolean} [parse=true] If false, the response will be returned in raw XML format
 * @param {Boolean} [async=true] If false, the request will be synchronous.
 * @param {Boolean} [addToUserInfoList=false] If true, the user will be added to the User Information List.
 * @returns {Object|Array<Object>} If parsing is true an array of objects is returns. If false an XML object is returned.
 * @returns
 */

var resolvePrincipals = function resolvePrincipals() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? $().SPServices.defaults.webURL || "" : _ref$webURL,
      _ref$principalType = _ref.principalType,
      principalType = _ref$principalType === void 0 ? "User" : _ref$principalType,
      principalKeys = _ref.principalKeys,
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async,
      _ref$parse = _ref.parse,
      parse = _ref$parse === void 0 ? true : _ref$parse,
      _ref$addToUserInfoLis = _ref.addToUserInfoList,
      addToUserInfoList = _ref$addToUserInfoLis === void 0 ? false : _ref$addToUserInfoLis;

  return new Promise(function (resolve, reject) {
    // If principalKeys is a string, cast to an array
    if (typeof principalKeys === "string") principalKeys = [principalKeys]; // If principalType is not User or SharePointGroup

    if (!["User", "SharePointGroup"].includes(principalType)) {
      // Reject with error
      return reject(new Error("The principalType of ".concat(principalType, " was incorrect.")));
    } // If principalKeys is not an array


    if (!Array.isArray(principalKeys)) {
      // Reject with error
      return reject(new Error("No searchText was provided"));
    } // Convert principalKeys to an string


    principalKeys = principalKeys.map(function (str) {
      return "<string>".concat(str, "</string>");
    }); // Send request

    $().SPServices({
      operation: "ResolvePrincipals",
      webURL: webURL,
      principalKeys: principalKeys,
      principalType: principalType,
      async: async,
      addToUserInfoList: addToUserInfoList,
      completefunc: function completefunc(xData, status) {
        // If an error occurred
        if (status === "error") {
          // Reject with error
          return reject({
            error: new Error("Error occurred when searching principals"),
            xData: xData
          });
        }

        try {
          // Get response
          var response = xData.responseXML; // If parse is truthy

          if (parse) {
            // Parse response
            response = _toConsumableArray(response.querySelectorAll("ResolvePrincipalsResult > PrincipalInfo")).map(function (principal) {
              return (// Create object from children (childNodes works with IE)
                _toConsumableArray(principal.childNodes).reduce(function (object, node) {
                  // Get object key
                  var key = node.nodeName; // Create string literal to store value

                  var value = ""; // Switch by key (nodeName)

                  switch (key) {
                    case "MoreMatches":
                      // Set value to be an array of objects containing user principals
                      value = _toConsumableArray(node.querySelectorAll("PrincipalInfo")).map(function (match) {
                        return _toConsumableArray(match.childNodes).reduce(function (object, node) {
                          object[node.nodeName] = node.textContent || "";

                          if (node.nodeName === "IsResolved") {
                            object[node.nodeName] = node.textContent === "true";
                          } else {
                            object[node.nodeName] = node.textContent || "";
                          }

                          return object;
                        }, {});
                      });
                      break;

                    case "IsResolved":
                      value = node.textContent === "true";
                      break;

                    default:
                      // Set value as node text content
                      value = node.textContent || "";
                      break;
                  } // Assign value to object


                  object[key] = value; // Return object/accumulator

                  return object;
                }, {})
              );
            });
          } // Resolve response


          resolve(response);
        } catch (error) {
          // Reject with error
          reject({
            error: error,
            xData: xData
          });
        }
      }
    });
  });
};

var _default = resolvePrincipals;
exports["default"] = _default;