"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

// External
var _window = window,
    $ = _window.$;
/**
 * @name searchPrincipals
 * @description Returns an array of PrincipalInfo objects from the SPUserCollection for the Web site. All instances have the principal logon name specified in searchText.
 * @param {Object} object
 * @param {String} searchText The Principal logon name.
 * @param {Number} [maxResults=10] The maximum results to be requested
 * @param {String} [webURL=window.$().SPServices.defaults.webURL] The relative webURL
 * @param {Boolean} [parse=true] If false, the response will be returned in raw XML format
 * @param {Boolean} [async=true] If false, the request will be synchronous.
 * @returns {Object|Array<Object>} If parsing is true an array of objects is returns. If false an XML object is returned.
 * @returns
 */

var searchPrincipals = function searchPrincipals() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      searchText = _ref.searchText,
      _ref$maxResults = _ref.maxResults,
      maxResults = _ref$maxResults === void 0 ? 100 : _ref$maxResults,
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? $().SPServices.defaults.webURL || "" : _ref$webURL,
      _ref$parse = _ref.parse,
      parse = _ref$parse === void 0 ? true : _ref$parse,
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async;

  return new Promise(function (resolve, reject) {
    // If no searchText is provided
    if (!searchText) {
      // Reject with error
      return reject(new Error("No searchText was provided"));
    } // Send request


    $().SPServices({
      operation: "SearchPrincipals",
      webURL: webURL,
      searchText: searchText,
      maxResults: maxResults,
      async: async,
      SPPrincipalType: "SPPrincipalType.User",
      completefunc: function completefunc(xData, status) {
        // If an error occurred
        if (status === "error") {
          // Reject with error
          return reject({
            error: new Error("Error occurred when searching principals"),
            xData: xData
          });
        }

        try {
          // Get response
          var response = xData.responseXML; // If parse is truthy

          if (parse) {
            // Parse response
            response = _toConsumableArray(response.querySelectorAll("PrincipalInfo")).map(function (principal) {
              return (// Create object from children (childNodes works with IE)
                _toConsumableArray(principal.childNodes).reduce(function (object, node) {
                  if (node.nodeName === "IsResolved") {
                    object[node.nodeName] = node.textContent === "true";
                  } else {
                    object[node.nodeName] = node.textContent || "";
                  }

                  return object;
                }, {})
              );
            });
          } // Resolve response


          resolve(response);
        } catch (error) {
          // Reject with error
          reject({
            error: error,
            xData: xData
          });
        }
      }
    });
  });
};

var _default = searchPrincipals;
exports["default"] = _default;