"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getUserGroupError = _interopRequireDefault(require("../../utils/errors/getUserGroupError"));

var _getUserGroupOptions = _interopRequireDefault(require("../../utils/options/getUserGroupOptions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name addGroup
 * @description Adds a group to the current site collection.
 * @param {object} options
 * @param {string} options.groupName - The group name.
 * - Required: Yes
 * @param {string} options.ownerIdentifier - The user name (domain\\username) or group name that owns the group.
 * - Required: Yes
 * @param {string} options.defaultUserLoginName - The default user that will be added to the group (domain\\username).
 * - Required: Yes
 * @param {string} [options.ownerType="group"] - Either user or group based on the type of owner identifier.
 * - Required: Yes
 * - Default: "group"
 * @param {string} [options.description=""] - The description of the group. This is not required but recommended.
 * - Required: No
 * - Default: ""
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
var addGroup = function addGroup(options) {
  return new Promise(function (resolve, reject) {
    var _getOptions = (0, _getUserGroupOptions["default"])(options),
        webURL = _getOptions.webURL,
        groupName = _getOptions.groupName,
        ownerIdentifier = _getOptions.ownerIdentifier,
        ownerType = _getOptions.ownerType,
        defaultUserLoginName = _getOptions.defaultUserLoginName,
        description = _getOptions.description,
        async = _getOptions.async;

    $().SPServices({
      operation: "AddGroup",
      webURL: webURL,
      async: async,
      groupName: groupName,
      ownerIdentifier: ownerIdentifier,
      ownerType: ownerType,
      defaultUserLoginName: defaultUserLoginName,
      description: description,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          resolve("Created Group: ".concat(groupName));
        } else {
          reject((0, _getUserGroupError["default"])(xData));
        }
      }
    });
  });
};

var _default = addGroup;
exports["default"] = _default;