"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getUserGroupError = _interopRequireDefault(require("../../utils/errors/getUserGroupError"));

var _getUserGroupOptions = _interopRequireDefault(require("../../utils/options/getUserGroupOptions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name addUserToGroup
 * @description Adds a group to the current site collection.
 * @param {object} options
 * @param {string} options.groupName - The group name.
 * - Required: Yes
 * @param {string} options.userLoginName - The user that will be added to the group (domain\\username).
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns responseXML on success or error object fail.
 */
var addUserToGroup = function addUserToGroup(options) {
  return new Promise(function (resolve, reject) {
    var _getOptions = (0, _getUserGroupOptions["default"])(options),
        webURL = _getOptions.webURL,
        groupName = _getOptions.groupName,
        userLoginName = _getOptions.userLoginName,
        async = _getOptions.async;

    $().SPServices({
      operation: "AddUserToGroup",
      webURL: webURL,
      async: async,
      groupName: groupName,
      userLoginName: userLoginName,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject((0, _getUserGroupError["default"])(xData));
        }
      }
    });
  });
};

var _default = addUserToGroup;
exports["default"] = _default;