"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getUserGroupError = _interopRequireDefault(require("../../utils/errors/getUserGroupError"));

var _getUserGroupOptions = _interopRequireDefault(require("../../utils/options/getUserGroupOptions"));

var _User = _interopRequireDefault(require("../../classes/userGroup/User"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name getAllUserCollectionFromWeb
 * @description turns information about the collection of users for the current Web site.
 * @required none
 * @param {object} options
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed with groups resolved
 * - Required: No
 * - Default: false
 * @returns {Promise} Returns a Promise XML result.
 */
var getAllUserCollectionFromWeb = function getAllUserCollectionFromWeb(options) {
  return new Promise(function (resolve, reject) {
    var _getOptions = (0, _getUserGroupOptions["default"])(options),
        webURL = _getOptions.webURL,
        async = _getOptions.async,
        parse = _getOptions.parse;

    $().SPServices({
      operation: "GetAllUserCollectionFromWeb",
      webURL: webURL,
      async: async,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          if (parse) {
            var groups = $(xData.responseXML).SPFilterNode("User").toArray().map(function (xml) {
              return new _User["default"]({
                xml: xml
              });
            });
            resolve(groups);
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject((0, _getUserGroupError["default"])(xData));
        }
      }
    });
  });
};

var _default = getAllUserCollectionFromWeb;
exports["default"] = _default;