"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getUserGroupError = _interopRequireDefault(require("../../utils/errors/getUserGroupError"));

var _getUserGroupOptions = _interopRequireDefault(require("../../utils/options/getUserGroupOptions"));

var _Group = _interopRequireDefault(require("../../classes/userGroup/Group"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name getGroupCollectionFromUser
 * @description Returns information about the collection of groups of which the specified user is a member.
 * @required options.userLoginName
 * @param {object} options
 * @param {string} options.userLoginName - A string that contains the user name (DOMAIN\User_Alias) of the user.
 * - Required: No
 * - Default: false
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed with groups resolved
 * - Required: No
 * - Default: false
 * @returns {Promise} Returns a Promise XML result.
 */
var getGroupCollectionFromUser = function getGroupCollectionFromUser(options) {
  return new Promise(function (resolve, reject) {
    var _getOptions = (0, _getUserGroupOptions["default"])(options),
        webURL = _getOptions.webURL,
        async = _getOptions.async,
        userLoginName = _getOptions.userLoginName,
        parse = _getOptions.parse;

    $().SPServices({
      operation: "GetGroupCollectionFromUser",
      userLoginName: userLoginName,
      webURL: webURL,
      async: async,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          if (parse) {
            var groups = [];
            $(xData.responseXML).SPFilterNode("Group").toArray().forEach(function (xml) {
              groups.push(new _Group["default"]({
                xml: xml
              }));
            });
            resolve(groups);
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject((0, _getUserGroupError["default"])(xData));
        }
      }
    });
  });
};

var _default = getGroupCollectionFromUser;
exports["default"] = _default;