"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getUserGroupError = _interopRequireDefault(require("../../utils/errors/getUserGroupError"));

var _getUserGroupOptions = _interopRequireDefault(require("../../utils/options/getUserGroupOptions"));

var _Response = _interopRequireDefault(require("../../classes/Response"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name getGroupInfo
 * @description Gets group information by name.
 * @required groupName
 * @param {object} options
 * @param {string} options.groupName - The group name as a string.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed into an object.
 * - Required: No
 * - Default: false
 * @returns {Promise} Returns a Promise XML result.
 */
var getGroupInfo = function getGroupInfo(options) {
  return new Promise(function (resolve, reject) {
    var _getOptions = (0, _getUserGroupOptions["default"])(options),
        webURL = _getOptions.webURL,
        async = _getOptions.async,
        parse = _getOptions.parse,
        groupName = _getOptions.groupName;

    $().SPServices({
      operation: "GetGroupInfo",
      groupName: groupName,
      webURL: webURL,
      async: async,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          if (parse) {
            var xml = Array.from(xData.responseXML.getElementsByTagName("Group"))[0];
            var group = {};

            if (group) {
              group = new _Response["default"]({
                xml: xml
              });
            }

            resolve(group);
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject((0, _getUserGroupError["default"])(xData));
        }
      }
    });
  });
};

var _default = getGroupInfo;
exports["default"] = _default;