"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getUserGroupError = _interopRequireDefault(require("../../utils/errors/getUserGroupError"));

var _getUserGroupOptions = _interopRequireDefault(require("../../utils/options/getUserGroupOptions"));

var _Response = _interopRequireDefault(require("../../classes/Response"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name getUserInfo
 * @description Gets user information by name.
 * @required userLoginName
 * @param {object} options
 * @param {string} options.userLoginName - The username as a string.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed into an object.
 * - Required: No
 * - Default: false
 * @returns {Promise} Returns a Promise XML result.
 */
var getUserInfo = function getUserInfo(options) {
  return new Promise(function (resolve, reject) {
    var _getOptions = (0, _getUserGroupOptions["default"])(options),
        webURL = _getOptions.webURL,
        async = _getOptions.async,
        parse = _getOptions.parse,
        userLoginName = _getOptions.userLoginName;

    $().SPServices({
      operation: "GetUserInfo",
      userLoginName: userLoginName,
      webURL: webURL,
      async: async,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          if (parse) {
            var xml = $(xData.responseXML).SPFilterNode("User")[0];
            var user = {};

            if (xml) {
              user = new _Response["default"]({
                xml: xml
              });
            }

            resolve(user);
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject((0, _getUserGroupError["default"])(xData));
        }
      }
    });
  });
};

var _default = getUserInfo;
exports["default"] = _default;