"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _assert = require("assert");

var _url = require("url");

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @name getUserCollectionFromSite
 * @description Returns information about the collection of users for the current site collection.
 * @required none
 * @param {object} options
 * @param {string} [options.oldGroupName] A string that contains the old name of the group.
 * @param {string} [options.groupName] A string that contains the new name of the group.
 * @param {string} [options.ownerIdentifier] A string that contains the user name (DOMAIN\User_Alias) for the owner of the group.
 * @param {string} [options.ownerType] A string that specifies the type of owner, which can be either user or group.
 * @param {string} [options.description] A string that contains the description for the group.
 * @param {string} [options.webURL=""] - The web site url.
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * @param {boolean} [options.parse=false] - XML will be parsed with groups resolved
 * @returns {Promise} Returns a Promise XML result.
 */
var updateGroupInfo = function updateGroupInfo() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      oldGroupName = _ref.oldGroupName,
      groupName = _ref.groupName,
      ownerIdentifier = _ref.ownerIdentifier,
      _ref$ownerType = _ref.ownerType,
      ownerType = _ref$ownerType === void 0 ? "group" : _ref$ownerType,
      _ref$description = _ref.description,
      description = _ref$description === void 0 ? "" : _ref$description,
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? "" : _ref$webURL,
      _ref$parse = _ref.parse,
      parse = _ref$parse === void 0 ? false : _ref$parse,
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async;

  return new Promise(function (resolve, reject) {
    $().SPServices({
      operation: "UpdateGroupInfo",
      oldGroupName: oldGroupName,
      groupName: groupName,
      ownerIdentifier: ownerIdentifier,
      ownerType: ownerType,
      description: description,
      webURL: webURL,
      sync: async,
      completefunc: function completefunc(xData, status) {
        var error = _toConsumableArray(xData.responseXML.querySelectorAll("*")).filter(function (_ref2) {
          var nodeName = _ref2.nodeName;
          return nodeName === "errorstring";
        });

        if (error.length > 0) {
          reject(error[0].textContent);
        }

        resolve();
      }
    });
  });
};

var _default = updateGroupInfo;
exports["default"] = _default;