"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @name getVersions
 * @description Returns information about the versions of the specified file.
 * @param {Object} payload The configuration payload object
 * @param {String} payload.fileName A string that contains the site-relative URL of the file in the form library/folder/File_Name (Do Not include the webURL).
 * @param {String} [payload.webURL=window.$().SPServices.defaults.webURL] The web site url
 * @param {Boolean} [payload.async=true] If false, the request will be synchronous (deprecated)
 * @param {Boolean} [payload.parse=false] If true, the response will be passed
 * @returns {Promise<Array|Object>} Returns an XML document unless parsing is true, then an array of objects is returned
 */
var getVersions = function getVersions() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      fileName = _ref.fileName,
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? window.$().SPServices.defaults.webURL || "" : _ref$webURL,
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async,
      _ref$parse = _ref.parse,
      parse = _ref$parse === void 0 ? false : _ref$parse;

  return new Promise(function (resolve, reject) {
    // Validate request
    if (!fileName) return reject("Missing fileName. Unable to send request"); // Send Request

    $().SPServices({
      operation: "GetVersions",
      webURL: webURL,
      async: async,
      fileName: fileName,
      completefunc: function completefunc(xData, status) {
        // Create reponse variable
        var response = xData.responseXML || null;

        switch (status) {
          case "error":
            if (response) {
              try {
                response = response.querySelector("errorstring").textContent;
              } catch (error) {
                response = "Unable to get response data from the server: ".concat(error.message);
              }
            }

            return reject(response);

          case "success":
            // If parse is true
            if (parse) {
              // Parse the response
              response = _toConsumableArray(response.querySelectorAll("result")).map(function (result) {
                return _toConsumableArray(result.attributes).reduce(function (object, _ref2) {
                  var nodeName = _ref2.nodeName,
                      nodeValue = _ref2.nodeValue;
                  object[nodeName] = nodeValue;
                  return object;
                }, {});
              });
            } // Resolve the response


            resolve(response);
            break;

          default:
            resolve(xData.responseXML);
            break;
        }
      }
    });
  });
};

var _default = getVersions;
exports["default"] = _default;