"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getViewOptions2 = _interopRequireDefault(require("../../utils/options/getViewOptions"));

var _getViewError = _interopRequireDefault(require("../../utils/errors/getViewError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name addView
 * @description Creates a view for the specified list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - A string that contains the internal name of the list.
 * - Required: Yes
 * @param {string} [options.viewName="CustomView_Date.now()"] - A string that contains the internal/display of the view.
 * - Required: No
 * - Default: "CustomView_1546488633686"
 * @param {string} [options.viewFields="<ViewFields><FieldRef Name='Title' /></ViewFields>"] - A string of XML that contains the CAML View Fields.
 * - Required: No
 * - Default: "<ViewFields><FieldRef Name='Title' /></ViewFields>"
 * @param {string} [options.query="<Query></Query>"] - A string of XML that contains the CAML Query.
 * - Required: No
 * - Default: "<Query></Query>"
 * @param {string} [options.rowLimit="<RowLimit paged='True'>100</RowLimit>"] - A string that specifies the number of items, or rows, to display on a page before paging begins, and that can be assigned to a System.Xml.XmlNode object. The fragment can include the Paged attribute to specify that the view return list items in pages.
 * - Required: No
 * - Default: "<RowLimit paged='True'>100</RowLimit>"
 * @param {string} [options.type="HTML"] - A string that specifies whether the view is an HTML view or a Datasheet view. Possible values include HTML and Grid.
 * - Required: No
 * - Default: "HTML"
 * @param {boolean} [options.makeDefaultView=""] - A boolean that sets the view as default if true.
 * - Required: No
 * - Default: false
 * @param {string} [options.webURL=""] - A string that contains the web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - A boolean that sets the synchronisation type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
var addView = function addView(options) {
  return new Promise(function (resolve, reject) {
    var _getViewOptions = (0, _getViewOptions2["default"])(options),
        webURL = _getViewOptions.webURL,
        async = _getViewOptions.async,
        listName = _getViewOptions.listName,
        viewName = _getViewOptions.viewName,
        viewFields = _getViewOptions.viewFields,
        query = _getViewOptions.query,
        rowLimit = _getViewOptions.rowLimit,
        type = _getViewOptions.type,
        makeViewDefault = _getViewOptions.makeViewDefault;

    $().SPServices({
      operation: "AddView",
      webURL: webURL,
      async: async,
      listName: listName,
      viewName: viewName,
      viewFields: viewFields,
      query: query,
      rowLimit: rowLimit,
      type: type,
      makeViewDefault: makeViewDefault,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject((0, _getViewError["default"])(xData));
        }
      }
    });
  });
};

var _default = addView;
exports["default"] = _default;