"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getNodeAttributes = _interopRequireDefault(require("../../utils/general/getNodeAttributes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @name getViewHtml
 * @description Get HTML from a view
 * @param {Object} payload
 * @param {String} [payload.webURL=window.$().SPServices.defaults.webURL] The web site url.
 * @param {Boolean} [payload.async=true] If false, the request will be synchronous.
 * @param {Boolean} [payload.parse=true] If false, the raw xml document will be resolved.
 * @returns {Promise<Object>} Resolves an object.
 * @example
 * getViewHtml({
 *  listName: "Announcements",
 *  viewName: "{315748D1-8FF2-4252-B88C-995B9179FB72}"
 * }).then(res => console.info(res))
 */
var getViewHtml = function getViewHtml() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? window.$().SPServices.defaults.webURL : _ref$webURL,
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async,
      _ref$parse = _ref.parse,
      parse = _ref$parse === void 0 ? true : _ref$parse,
      listName = _ref.listName,
      viewName = _ref.viewName;

  return new Promise(function (resolve, reject) {
    $().SPServices({
      operation: "GetViewHtml",
      webURL: webURL,
      listName: listName,
      viewName: viewName,
      async: async,
      completefunc: function completefunc(xData, status) {
        try {
          // If error
          if (status !== "success") return reject(xData); // Get XML

          var xml = xData.responseXML; // If parse is false

          if (!parse) {
            // Resolve XML
            return resolve(xml);
          } // Get view Props


          var View = (0, _getNodeAttributes["default"])(xml.querySelector("View")); // Convert ViewFields into array

          var ViewFields = _toConsumableArray(xml.querySelectorAll("ViewFields FieldRef")).map(function (node) {
            return node.getAttribute("Name");
          }); // Convert Query into String


          var Query = new XMLSerializer().serializeToString(xml.querySelector("Query")); // Get Row Limit Element

          var RowLimit = xml.querySelector("RowLimit"); // Check if paged

          var Paged = RowLimit ? RowLimit.getAttribute("Paged") : false; // Get Row Limit

          RowLimit = (RowLimit || {}).textContent || ""; // Get Toolbar

          var Toolbar = xml.querySelector("Toolbar").getAttribute("Type"); // Resolve

          resolve(_objectSpread(_objectSpread({}, View), {}, {
            ViewFields: ViewFields,
            Query: Query,
            RowLimit: RowLimit,
            Paged: Paged,
            Toolbar: Toolbar
          }));
        } catch (error) {
          reject(xData, error);
        }
      }
    });
  });
};

var _default = getViewHtml;
exports["default"] = _default;