"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getWebPartPagesError = _interopRequireDefault(require("../../utils/errors/getWebPartPagesError"));

var _getWebPartPagesOptions = _interopRequireDefault(require("../../utils/options/getWebPartPagesOptions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name deleteWebPartPage
 * @description Deletes a dynamic Web Part from a Web Part Page.
 * @required pageUrl
 * @param {object} options
 * @param {string} options.pageUrl - A string containing the URL of the Web Part Page.
 * - Required: Yes
 * @param {string} options.storageKey - A GUID that identifies of the Web Part.
 * - Required: Yes
 * @param {string} [options.storage="Shared"] - A Storage value indicating how the Web Part was stored.
 * - Required: No
 * - Default: "Shared"
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
var deleteWebPartPage = function deleteWebPartPage(options) {
  var _getWebPartPagesOptio = (0, _getWebPartPagesOptions["default"])(options),
      webURL = _getWebPartPagesOptio.webURL,
      pageUrl = _getWebPartPagesOptio.pageUrl,
      storageKey = _getWebPartPagesOptio.storageKey,
      storage = _getWebPartPagesOptio.storage,
      async = _getWebPartPagesOptio.async;

  return new Promise(function (resolve, reject) {
    $().SPServices({
      operation: "DeleteWebPart",
      webURL: webURL,
      pageUrl: pageUrl,
      storageKey: storageKey,
      storage: storage,
      async: async,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject((0, _getWebPartPagesError["default"])(xData));
        }
      }
    });
  });
};

var _default = deleteWebPartPage;
exports["default"] = _default;