"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getWebPartPagesError = _interopRequireDefault(require("../../utils/errors/getWebPartPagesError"));

var _getWebPartPagesOptions = _interopRequireDefault(require("../../utils/options/getWebPartPagesOptions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name getWebPartProperties
 * @description Returns an XML string of all Web Parts associated with a Web Part Page.
 * @required pageUrl
 * @param {object} options
 * @param {string} options.pageUrl - A string containing the URL of the Web Part Page.
 * - Required: Yes
 * @param {boolean} [options.parse=false] - Parse the response and return as JSON.
 * - Required: No
 * - Default: false
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
var getWebPartProperties = function getWebPartProperties(options) {
  return new Promise(function (resolve, reject) {
    var _getWebPartPagesOptio = (0, _getWebPartPagesOptions["default"])(options),
        webURL = _getWebPartPagesOptio.webURL,
        pageUrl = _getWebPartPagesOptio.pageUrl,
        parse = _getWebPartPagesOptio.parse,
        timeout = _getWebPartPagesOptio.timeout,
        storage = _getWebPartPagesOptio.storage,
        async = _getWebPartPagesOptio.async;

    $().SPServices({
      operation: "GetWebPartProperties",
      webURL: webURL,
      pageUrl: pageUrl,
      storage: storage,
      parse: parse,
      timeout: timeout,
      async: async,
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          // If parsing is not required.
          if (!parse) {
            resolve(xData.responseXML);
          } else {
            // If parsing is required
            var webParts = [];
            $(xData.responseXML).SPFilterNode("WebPart").each(function () {
              // Current Row
              var row = this; // Web Part

              var webPart = {}; // Get Attributes

              var attributes = row.attributes;

              for (var i = 0; i < attributes.length; i++) {
                var attribute = attributes[i];
                var key = "_".concat(attribute.name);
                webPart[key] = attribute.value;
              } // Get XML Children Nodes


              $(row).children().each(function () {
                webPart[this.nodeName] = $(this).text();
              });
              webParts.push(webPart);
            });
            resolve(webParts);
          }
        } else {
          reject((0, _getWebPartPagesError["default"])(xData));
        }
      }
    });
  });
};

var _default = getWebPartProperties;
exports["default"] = _default;