"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getWebError = _interopRequireDefault(require("../../utils/errors/getWebError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

var _window = window,
    $ = _window.$;
/**
 * @name getWeb
 * @description Returns properties of a site (for example, name, description, and theme).
 * @param {object} options
 * @param {string} [options.webURL=""] A string that contains the relative URL of the site.
 * @param {boolean} [options.async=true] If true, the request is asynchronous.
 * @param {boolean} [options.parse=false] If true, the xml will be parsed into an object
 * @returns {object} Resolves a Promised XML string or object.
 */

var getWeb = function getWeb() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? $().SPServices.defaults.webURL || "" : _ref$webURL,
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async,
      _ref$parse = _ref.parse,
      parse = _ref$parse === void 0 ? false : _ref$parse;

  return new Promise(function (resolve, reject) {
    $().SPServices({
      operation: "GetWeb",
      webURL: webURL,
      async: async,
      completefunc: function completefunc(xData, status) {
        var responseXML = xData.responseXML; // If success

        if (status === "success") {
          // If parse
          if (parse) {
            // Convert response into object
            var web = responseXML.getElementsByTagName("Web")[0]; // If web is found in response XML

            if (web) {
              web = _toConsumableArray(web.attributes).reduce(function (web, attribute) {
                web[attribute.name] = attribute.value;
                return web;
              }, {});
            } else {
              // Web was not found, set to object literal
              web = {};
            } // Resolve web


            resolve(web);
          } else {
            resolve(responseXML);
          }
        } else {
          reject((0, _getWebError["default"])(xData));
        }
      }
    });
  });
};

var _default = getWeb;
exports["default"] = _default;