"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getNodeAttributes = _interopRequireDefault(require("../../utils/general/getNodeAttributes"));

var _convertStringToXml = _interopRequireDefault(require("../../utils/general/convertStringToXml"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @name getTemplatesForItem
 * @param {Object} payload
 * @param {String} payload.itemURL The URL location of an item on which a workflow is being run.
 * @param {String} [payload.webURL=window.$().SPServices.defaults.webURL] The web site url.
 * @param {Boolean} [payload.async=true] If false, the request will be synchronous.
 * @param {Boolean} [payload.parse=true] If false, the raw xml document will be resolved.
 * @returns {Promise<Object>} Resolves a promised object contains workflow data or a XML document.
 * getTemplatesForItem({
 *  webURL: "/sites/development",
 *  itemURL: "http://kingsolutions/sites/development/Lists/DemoList/1_.000",
 *  parse: true,
 *  async: true,
 * })
 */
var getTemplatesForItem = function getTemplatesForItem(_ref) {
  var _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async,
      itemURL = _ref.itemURL,
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? window.$().SPServices.defaults.webURL : _ref$webURL,
      _ref$parse = _ref.parse,
      parse = _ref$parse === void 0 ? true : _ref$parse;
  return new Promise(function (resolve, reject) {
    $().SPServices({
      operation: "GetTemplatesForItem",
      webURL: webURL,
      item: itemURL,
      async: async,
      completefunc: function completefunc(xData, status) {
        // If status is not success
        if (status === "error") {
          // Return with rejected data
          return reject(xData, status);
        } // Get XML document


        var xml = xData.responseXML; // If XML is not defined

        if (!xml) {
          // Convert String to XML
          xml = (0, _convertStringToXml["default"])(xData.responseText || ""); // If XML is not defined, reject with error

          if (!xml) {
            // Return/reject error
            return reject(xData, status);
          }
        } // If parsing is not required


        if (!parse) {
          // Resolve raw xml document
          return resolve(xml);
        } // Create response object


        var response = {}; // Get web

        response.Web = (0, _getNodeAttributes["default"])(xml.querySelector("Web")); // Get list

        response.List = (0, _getNodeAttributes["default"])(xml.querySelector("List")); // Get Workflow Templates

        response.WorkflowTemplates = _toConsumableArray(xml.querySelectorAll("WorkflowTemplate")).map(function (node) {
          // Get current template
          var object = (0, _getNodeAttributes["default"])(node); // Get Template ID Set

          object.WorkflowTemplateIdSet = (0, _getNodeAttributes["default"])(node.querySelector("WorkflowTemplateIdSet"));
          return object;
        }); // Return response object

        return resolve(response);
      }
    });
  });
};

var _default = getTemplatesForItem;
exports["default"] = _default;