/**
 * @name copyIntoItems
 * @description Copies a document represented by a Byte array to one or more locations on a server.
 * @param {Object} payload
 * @param {String} [payload.sourceUrl=" "] A String that contains the absolute source URL of the document to be copied.
 * @param {Array|String} payload.destinationUrls - A String or an array of Strings that contain one or more absolute URLs specifying the destination location or locations of the copied document.
 * @param {String} payload.stream - The base 64 data string.
 * @param {String} [payload.webURL=""] - The web site url.
 * @param {Boolean} [payload.async=true] If false, the request will be synchronous.
 * @returns {Promise} Returns a Promise with the response as XML.
 */
const copyIntoItems = ({
  async = false,
  destinationUrls,
  sourceUrl = " ",
  stream,
  webURL = window.$().SPServices.defaults.webURL
}) =>
  new Promise((resolve, reject) => {
    {
      const DestinationUrls = Array.isArray(destinationUrls)
        ? destinationUrls
        : [destinationUrls];

      window.$().SPServices({
        operation: "CopyIntoItems",
        webURL,
        // The SourceUrl is required and cannot be blank. Adding a space forces the string to be truly and SharePoint accepts the request. If blank the request fails.
        SourceUrl: sourceUrl,
        DestinationUrls,
        Stream: stream,
        async,
        completefunc: function(xData, status) {
          if (status === "success") {
            resolve(xData.responseXML);
          } else {
            reject(xData.responseXML);
          }
        }
      });
    }
  });
export default copyIntoItems;
