import getListsError from "../../utils/errors/getListsError";
import getListsOptions from "../../utils/options/getListsOptions";
/**
 * @name addAttachment
 * @description Adds an attachment to the specified list item in the specified list.
 * @required listName, listItemID, fileName, attachment
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {string} options.listItemID - The list item ID.
 * - Required: Yes
 * @param {string} options.fileName - The filename that will be created.
 * - Required: Yes
 * @param {string} options.attachment - The base 64 data string.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
const addAttachment = options => {
  return new Promise((resolve, reject) => {
    const {
      webURL,
      listName,
      async,
      listItemID,
      fileName,
      attachment
    } = getListsOptions(options);

    $().SPServices({
      operation: "AddAttachment",
      webURL,
      listName,
      async,
      listItemID,
      fileName,
      attachment,
      completefunc: (xData, status) => {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject(getListsError(xData));
        }
      }
    });
  });
};

export default addAttachment;
