import getListsError from "../../utils/errors/getListsError";

/**
 * @name deleteAttachment
 * @description Adds an attachment to the specified list item in the specified list.
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * @param {string} options.listItemID - The list item ID.
 * @param {string} options.url - A string that contains the absolute URL for the attachment
 * @param {string} [options.webURL=""] - The web site url.
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * @returns {Promise} Returns a Promise XML result.
 * @example
 * deleteAttachment({
 * webURL: "http://objectpoint/sites/development",
 *  listName: "Delete Attachment",
 *  listItemID: 1,
 *  url:
 *    "http://objectpoint/sites/development/Lists/DeleteAttachment/Attachments/1/report.docx"
 * }).then(res => {
 *  console.info("res", res);
 * });
 */
const deleteAttachment = ({
  async = true,
  listItemID,
  listName,
  url,
  webURL = window.$().SPServices.defaults.webURL,
}) => {
  return new Promise((resolve, reject) => {
    $().SPServices({
      operation: "DeleteAttachment",
      webURL,
      listName,
      async,
      listItemID,
      url,
      completefunc: (xData, status) => {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject(getListsError(xData));
        }
      },
    });
  });
};

export default deleteAttachment;
