import getListsError from "../../utils/errors/getListsError";
import getListsOptions from "../../utils/options/getListsOptions";
import parseList from "../../utils/lists/parseList";

/**
 * @name getList
 * @description Get a schema for the specified list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * @param {string} [options.webURL=window.$().SPServices.defaults.webURL] - The web site url
 * @param {boolean} [options.parse=false] - XML will be parsed with items return
 * @param {boolean} [options.readOnlyColumns=null] - Read only columns will be returned
 * @param {boolean} [options.viewColumns=null] - Only columns that are selectable in views will be returned
 * @param {boolean} [options.hiddenColumns=null] - Hidden columns will be returned
 * @param {boolean} [options.customColumns=null] - Custom columns will be returned
 * @param {boolean} [options.columnAttributes=[]] - Array of column attribute names will return only those attributes
 * @param {boolean} [options.async=true] - Synchronisation Type
 * @returns {Promise} Returns a Promise XML result.
 */
const getList = (options) => {
  return new Promise((resolve, reject) => {
    const {
      webURL,
      listName,
      parse,
      async,
      readOnlyColumns,
      hiddenColumns,
      customColumns,
      columnAttributes,
      viewColumns,
    } = getListsOptions(options);

    $().SPServices({
      operation: "GetList",
      webURL,
      listName,
      async,
      completefunc: (xData, status) => {
        if (status === "success") {
          if (parse) {
            parseList({
              xml: xData.responseXML,
              readOnlyColumns,
              hiddenColumns,
              customColumns,
              columnAttributes,
              viewColumns,
            }).then((list) => {
              resolve(list);
            });
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject(getListsError(xData));
        }
      },
    });
  });
};
export default getList;
