import getListsError from "../../utils/errors/getListsError";
import getListsOptions from "../../utils/options/getListsOptions";
import Response from "../../classes/Response";

/**
 * @name getListCollection
 * @required null
 * @description Get the names and GUIDs for all lists in the site.
 * @param {object} options
 * @param {string} [options.webURL=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.parse=false] - XML will be parsed with items return
 * - Required: No
 * - Default: false
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
const getListCollection = options => {
  return new Promise((resolve, reject) => {
    const { webURL, async, parse } = getListsOptions(options);
    $().SPServices({
      operation: "GetListCollection",
      webURL,
      async,
      completefunc: (xData, status) => {
        if (status === "success") {
          if (parse) {
            let lists = [];
            $(xData.responseXML)
              .SPFilterNode("List")
              .each(function() {
                lists.push(new Response({ xml: this }));
              });
            resolve(lists);
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject(getListsError(xData));
        }
      }
    });
  });
};

export default getListCollection;
