/**
 * @name getVersionCollection
 * @description Returns information about items in the list based on the specified query.
 * @required listName
 * @param {Object} payload The configuration payload object
 * @param {String} payload.listName The list display name or GUID
 * @param {String} [payload.webURL=window.$().SPServices.defaults.webURL || ""] The web site url
 * @param {String} [payload.field="Title"] The field static name to retrieve version history.
 * @param {Boolean} [payload.parse=false] If true, the response will be passed
 */
const getVersionCollection = ({
  ID,
  listName,
  webURL = $().SPServices.defaults.webURL,
  async = true,
  field = "Title",
  parse = false,
}) => {
  return new Promise((resolve, reject) => {
    $().SPServices({
      operation: "GetVersionCollection",
      webURL,
      async,
      strlistID: listName,
      strlistItemID: ID,
      strFieldName: field,
      completefunc: function (xData, status) {
        let res = xData.responseXML;
        if (status === "success") {
          if (parse) {
            const items = [...res.querySelectorAll("Version")].map((xml) => ({
              Modified: xml.getAttribute("Modified"),
              Editor: xml.getAttribute("Editor"),
              [field]: xml.getAttribute(field),
            }));
            resolve(items);
          } else {
            resolve(res);
          }
        } else {
          let message = [...res.querySelectorAll("*")].find(
            ({ nodeName }) => nodeName === "errorstring"
          );

          if (message) {
            message = message.innerHTML;
          }

          reject({
            message: message,
            code: xData.status,
            status: xData.statusText,
          });
        }
      },
    });
  });
};

export default getVersionCollection;
