import getNodeAttributes from "../../utils/general/getNodeAttributes";
import MASKS, { ALL_WEB_MASKS, ALL_LIST_MASKS } from "../../constants/masks";

const getPermissionCollection = ({
  isWeb = true,
  name,
  parse = true,
  webURL = window.$().SPServices.defaults.webURL,
  async = true,
} = {}) =>
  new Promise((resolve, reject) => {
    $().SPServices({
      operation: "GetPermissionCollection",
      webURL,
      objectName: name,
      objectType: isWeb ? "Web" : "List",
      async,
      completefunc: function (xData, status) {
        // If status is not success
        if (status !== "success") return reject(xData);

        // If parse is false, resolve XML
        if (!parse) return resolve(xData.responseXML);

        const permissions = [
          ...xData.responseXML.querySelectorAll("Permission"),
        ].map((node) => {
          let permission = getNodeAttributes(node);
          const MASKS = isWeb ? ALL_WEB_MASKS : ALL_LIST_MASKS;

          MASKS.forEach((MASK) => {
            permission[MASK.STATIC_NAME] =
              MASK.VALUE & (permission.Mask.toString(16) > 0) ? true : false;
          });
          return permission;
        });
        resolve(permissions);
      },
    });
  });

export default getPermissionCollection;
