const { $ } = window;
const parser = new DOMParser();

/**
 * @name siteDataGetList
 * @description Returns metadata from the specified SharePoint list.
 * @param {object} options
 * @param {string} options.listName A string that contains either the name of the list or the GUID of the list enclosed in curly braces ({}).
 * @param {string} [options.webURL=""] The relative or absolute webURL.
 * @param {boolean} [options.async=true] If true, the web request will be asynchronous.
 * @returns {Promise}
 */
const siteDataGetList = ({ webURL = "", listName, async = true } = {}) => {
  return new Promise((resolve, reject) => {
    $().SPServices({
      operation: "SiteDataGetList",
      webURL,
      strListName: listName,
      async,
      completefunc: function({ responseXML }, status) {
        // If success
        if (status === "success") {
          // Get list fromx ml
          let list = [
            ...responseXML.querySelector("sListMetadata").children
          ].reduce((object, node) => {
            object[node.nodeName] = node.textContent;
            return object;
          }, {});

          // Get permissions (if found)
          const permissionsXML = parser.parseFromString(
            list.Permissions,
            "text/xml"
          );

          // Get list permission objects
          list.Permissions = [
            ...permissionsXML.querySelectorAll("Permission")
          ].map(node => {
            return [...node.attributes].reduce(
              (object, { nodeName, nodeValue }) => {
                object[nodeName] = nodeValue;
                return object;
              },
              {}
            );
          });

          // Resolve list
          resolve(list);
        } else {
          reject("Error getting site data list");
        }
      }
    });
  });
};
export default siteDataGetList;
