import getUserGroupError from "../../utils/errors/getUserGroupError";
import getOptions from "../../utils/options/getUserGroupOptions";
/**
 * @name addGroup
 * @description Adds a group to the current site collection.
 * @param {object} options
 * @param {string} options.groupName - The group name.
 * - Required: Yes
 * @param {string} options.ownerIdentifier - The user name (domain\\username) or group name that owns the group.
 * - Required: Yes
 * @param {string} options.defaultUserLoginName - The default user that will be added to the group (domain\\username).
 * - Required: Yes
 * @param {string} [options.ownerType="group"] - Either user or group based on the type of owner identifier.
 * - Required: Yes
 * - Default: "group"
 * @param {string} [options.description=""] - The description of the group. This is not required but recommended.
 * - Required: No
 * - Default: ""
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
const addGroup = options => {
  return new Promise((resolve, reject) => {
    const {
      webURL,
      groupName,
      ownerIdentifier,
      ownerType,
      defaultUserLoginName,
      description,
      async
    } = getOptions(options);

    $().SPServices({
      operation: "AddGroup",
      webURL,
      async,
      groupName,
      ownerIdentifier,
      ownerType,
      defaultUserLoginName,
      description,
      completefunc: (xData, status) => {
        if (status === "success") {
          resolve(`Created Group: ${groupName}`);
        } else {
          reject(getUserGroupError(xData));
        }
      }
    });
  });
};

export default addGroup;
