import getUserGroupError from "../../utils/errors/getUserGroupError";
import getOptions from "../../utils/options/getUserGroupOptions";
import User from "../../classes/userGroup/User";
/**
 * @name getAllUserCollectionFromWeb
 * @description turns information about the collection of users for the current Web site.
 * @required none
 * @param {object} options
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed with groups resolved
 * - Required: No
 * - Default: false
 * @returns {Promise} Returns a Promise XML result.
 */
const getAllUserCollectionFromWeb = options => {
  return new Promise((resolve, reject) => {
    const { webURL, async, parse } = getOptions(options);
    $().SPServices({
      operation: "GetAllUserCollectionFromWeb",
      webURL,
      async,
      completefunc: (xData, status) => {
        if (status === "success") {
          if (parse) {
            let groups = $(xData.responseXML)
              .SPFilterNode("User")
              .toArray()
              .map(xml => {
                return new User({ xml });
              });
            resolve(groups);
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject(getUserGroupError(xData));
        }
      }
    });
  });
};

export default getAllUserCollectionFromWeb;
