import getUserGroupError from "../../utils/errors/getUserGroupError";
import getOptions from "../../utils/options/getUserGroupOptions";
import Group from "../../classes/userGroup/Group";
/**
 * @name getGroupCollectionFromUser
 * @description Returns information about the collection of groups of which the specified user is a member.
 * @required options.userLoginName
 * @param {object} options
 * @param {string} options.userLoginName - A string that contains the user name (DOMAIN\User_Alias) of the user.
 * - Required: No
 * - Default: false
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed with groups resolved
 * - Required: No
 * - Default: false
 * @returns {Promise} Returns a Promise XML result.
 */
const getGroupCollectionFromUser = options => {
  return new Promise((resolve, reject) => {
    const { webURL, async, userLoginName, parse } = getOptions(options);
    $().SPServices({
      operation: "GetGroupCollectionFromUser",
      userLoginName,
      webURL,
      async,
      completefunc: (xData, status) => {
        if (status === "success") {
          if (parse) {
            let groups = [];
            $(xData.responseXML)
              .SPFilterNode("Group")
              .toArray()
              .forEach(xml => {
                groups.push(new Group({ xml }));
              });
            resolve(groups);
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject(getUserGroupError(xData));
        }
      }
    });
  });
};

export default getGroupCollectionFromUser;
