import getUserGroupError from "../../utils/errors/getUserGroupError";
import getOptions from "../../utils/options/getUserGroupOptions";
import Response from "../../classes/Response";
/**
 * @name getGroupInfo
 * @description Gets group information by name.
 * @required groupName
 * @param {object} options
 * @param {string} options.groupName - The group name as a string.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed into an object.
 * - Required: No
 * - Default: false
 * @returns {Promise} Returns a Promise XML result.
 */
const getGroupInfo = options => {
  return new Promise((resolve, reject) => {
    const { webURL, async, parse, groupName } = getOptions(options);

    $().SPServices({
      operation: "GetGroupInfo",
      groupName,
      webURL,
      async,
      completefunc: function(xData, status) {
        if (status === "success") {
          if (parse) {
            let xml = Array.from(
              xData.responseXML.getElementsByTagName("Group")
            )[0];
            let group = {};
            if (group) {
              group = new Response({ xml });
            }
            resolve(group);
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject(getUserGroupError(xData));
        }
      }
    });
  });
};

export default getGroupInfo;
