import getUserGroupError from "../../utils/errors/getUserGroupError";

const { $ } = window;
/**
 * @name getRolesAndPermissionsForSite
 * @description Retrieves permissions and role definitions for the specified Web site.
 * @param {object} options
 * @param {string} [options.webURL=""] A string that contains the relative URL of the site.
 * @param {boolean} [options.async=true] If true, the request is asynchronous.
 * @param {boolean} [options.parse=false] If true, the xml will be parsed into an object
 * @returns {object} Resolves a Promised XML string or object.
 */
const getRolesAndPermissionsForSite = ({
  webURL = $().SPServices.defaults.webURL || "",
  async = true,
  parse = false
} = {}) => {
  return new Promise((resolve, reject) => {
    $().SPServices({
      operation: "GetRolesAndPermissionsForSite",
      webURL,
      async,
      parse,
      completefunc: function(xData, status) {
        const responseXML = xData.responseXML;
        // If success
        if (status === "success") {
          // If parse
          if (parse) {
            // Convert response into array
            let array = [...responseXML.getElementsByTagName("Role")].map(xml =>
              [...xml.attributes].reduce((object, attribute) => {
                object[attribute.name] = attribute.value;
                return object;
              }, {})
            );

            // Resolve web
            resolve(array);
          } else {
            resolve(responseXML);
          }
        } else {
          reject(getUserGroupError(xData));
        }
      }
    });
  });
};

export default getRolesAndPermissionsForSite;
