import getUserGroupError from "../../utils/errors/getUserGroupError";
import getOptions from "../../utils/options/getUserGroupOptions";
import User from "../../classes/userGroup/User";
/**
 * @name getUserCollectionFromGroup
 * @description Returns information about the collection of users for specified group.
 * @required none
 * @param {object} options
 * @param {string} options.groupName - The name of the group.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed with groups resolved
 * - Required: No
 * - Default: false
 * @returns {Promise} Returns a Promise XML result.
 */
const getUserCollectionFromGroup = options => {
  return new Promise((resolve, reject) => {
    const { webURL, async, parse, groupName } = getOptions(options);
    $().SPServices({
      operation: "GetUserCollectionFromGroup",
      groupName,
      webURL,
      async,
      completefunc: (xData, status) => {
        if (status === "success") {
          if (parse) {
            let array = $(xData.responseXML)
              .SPFilterNode("User")
              .toArray()
              .map(xml => {
                return new User({ xml });
              });
            resolve(array);
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject(getUserGroupError(xData));
        }
      }
    });
  });
};

export default getUserCollectionFromGroup;
