import getUserGroupError from "../../utils/errors/getUserGroupError";
import getOptions from "../../utils/options/getUserGroupOptions";
import Response from "../../classes/Response";
/**
 * @name getUserInfo
 * @description Gets user information by name.
 * @required userLoginName
 * @param {object} options
 * @param {string} options.userLoginName - The username as a string.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed into an object.
 * - Required: No
 * - Default: false
 * @returns {Promise} Returns a Promise XML result.
 */

const getUserInfo = options => {
  return new Promise((resolve, reject) => {
    const { webURL, async, parse, userLoginName } = getOptions(options);

    $().SPServices({
      operation: "GetUserInfo",
      userLoginName,
      webURL,
      async,
      completefunc: function(xData, status) {
        if (status === "success") {
          if (parse) {
            let xml = $(xData.responseXML).SPFilterNode("User")[0];
            let user = {};
            if (xml) {
              user = new Response({ xml });
            }
            resolve(user);
          } else {
            resolve(xData.responseXML);
          }
        } else {
          reject(getUserGroupError(xData));
        }
      }
    });
  });
};

export default getUserInfo;
