import getUserGroupError from "../../utils/errors/getUserGroupError";
import getOptions from "../../utils/options/getUserGroupOptions";
/**
 * @name removeUserFromGroup
 * @description Adds a group to the current site collection.
 * @param {object} options
 * @param {string} options.groupName - The group name.
 * - Required: Yes
 * @param {string} options.userLoginName - The user that will be added to the group (domain\\username).
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns responseXML on success or error object fail.
 */
const removeUserFromGroup = options => {
  return new Promise((resolve, reject) => {
    const { webURL, groupName, userLoginName, async } = getOptions(options);

    $().SPServices({
      operation: "RemoveUserFromGroup",
      webURL,
      async,
      groupName,
      userLoginName,
      completefunc: (xData, status) => {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject(getUserGroupError(xData));
        }
      }
    });
  });
};

export default removeUserFromGroup;
