import { rejects } from "assert";
import { resolve } from "url";

/**
 * @name getUserCollectionFromSite
 * @description Returns information about the collection of users for the current site collection.
 * @required none
 * @param {object} options
 * @param {string} [options.oldGroupName] A string that contains the old name of the group.
 * @param {string} [options.groupName] A string that contains the new name of the group.
 * @param {string} [options.ownerIdentifier] A string that contains the user name (DOMAIN\User_Alias) for the owner of the group.
 * @param {string} [options.ownerType] A string that specifies the type of owner, which can be either user or group.
 * @param {string} [options.description] A string that contains the description for the group.
 * @param {string} [options.webURL=""] - The web site url.
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * @param {boolean} [options.parse=false] - XML will be parsed with groups resolved
 * @returns {Promise} Returns a Promise XML result.
 */

const updateGroupInfo = ({
  oldGroupName,
  groupName,
  ownerIdentifier,
  ownerType = "group",
  description = "",
  webURL = "",
  parse = false,
  async = true
} = {}) =>
  new Promise((resolve, reject) => {
    $().SPServices({
      operation: "UpdateGroupInfo",
      oldGroupName,
      groupName,
      ownerIdentifier,
      ownerType,
      description,
      webURL,
      sync: async,
      completefunc: function(xData, status) {
        const error = [...xData.responseXML.querySelectorAll("*")].filter(
          ({ nodeName }) => nodeName === "errorstring"
        );

        if (error.length > 0) {
          reject(error[0].textContent);
        }

        resolve();
      }
    });
  });

export default updateGroupInfo;
