import getViewOptions from "../../utils/options/getViewOptions";
import getViewError from "../../utils/errors/getViewError";

/**
 * @name addView
 * @description Creates a view for the specified list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - A string that contains the internal name of the list.
 * - Required: Yes
 * @param {string} [options.viewName="CustomView_Date.now()"] - A string that contains the internal/display of the view.
 * - Required: No
 * - Default: "CustomView_1546488633686"
 * @param {string} [options.viewFields="<ViewFields><FieldRef Name='Title' /></ViewFields>"] - A string of XML that contains the CAML View Fields.
 * - Required: No
 * - Default: "<ViewFields><FieldRef Name='Title' /></ViewFields>"
 * @param {string} [options.query="<Query></Query>"] - A string of XML that contains the CAML Query.
 * - Required: No
 * - Default: "<Query></Query>"
 * @param {string} [options.rowLimit="<RowLimit paged='True'>100</RowLimit>"] - A string that specifies the number of items, or rows, to display on a page before paging begins, and that can be assigned to a System.Xml.XmlNode object. The fragment can include the Paged attribute to specify that the view return list items in pages.
 * - Required: No
 * - Default: "<RowLimit paged='True'>100</RowLimit>"
 * @param {string} [options.type="HTML"] - A string that specifies whether the view is an HTML view or a Datasheet view. Possible values include HTML and Grid.
 * - Required: No
 * - Default: "HTML"
 * @param {boolean} [options.makeDefaultView=""] - A boolean that sets the view as default if true.
 * - Required: No
 * - Default: false
 * @param {string} [options.webURL=""] - A string that contains the web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - A boolean that sets the synchronisation type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
const addView = options => {
  return new Promise((resolve, reject) => {
    const {
      webURL,
      async,
      listName,
      viewName,
      viewFields,
      query,
      rowLimit,
      type,
      makeViewDefault
    } = getViewOptions(options);
    $().SPServices({
      operation: "AddView",
      webURL,
      async,
      listName,
      viewName,
      viewFields,
      query,
      rowLimit,
      type,
      makeViewDefault,
      completefunc: function(xData, status) {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject(getViewError(xData));
        }
      }
    });
  });
};

export default addView;
