import getWebPartPagesError from "../../utils/errors/getWebPartPagesError";
import getWebPartPagesOptions from "../../utils/options/getWebPartPagesOptions";
/**
 * @name deleteWebPartPage
 * @description Deletes a dynamic Web Part from a Web Part Page.
 * @required pageUrl
 * @param {object} options
 * @param {string} options.pageUrl - A string containing the URL of the Web Part Page.
 * - Required: Yes
 * @param {string} options.storageKey - A GUID that identifies of the Web Part.
 * - Required: Yes
 * @param {string} [options.storage="Shared"] - A Storage value indicating how the Web Part was stored.
 * - Required: No
 * - Default: "Shared"
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
const deleteWebPartPage = options => {
  const {
    webURL,
    pageUrl,
    storageKey,
    storage,
    async
  } = getWebPartPagesOptions(options);

  return new Promise((resolve, reject) => {
    $().SPServices({
      operation: "DeleteWebPart",
      webURL,
      pageUrl,
      storageKey,
      storage,
      async,
      completefunc: function(xData, status) {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject(getWebPartPagesError(xData));
        }
      }
    });
  });
};

export default deleteWebPartPage;
