// const $ = window.$;
// let FIELDS = [];
// $().SPServices({
//   operation: "GetColumns",
//   async: false,
//   completefunc: ({ responseXML }) => {
//     FIELDS = Array.from(responseXML.getElementsByTagName("Field"))
//       .filter(field => {
//         const group = (field.getAttribute("Group") || "").toUpperCase();
//         return group === "SERVOPC";
//       })
//       .map((field, index) => {
//         field = field.outerHTML
//           .replace(` xmlns="http://schemas.microsoft.com/sharepoint/soap/"`, "")
//           .replace(/&/g, "&amp;");
//         const method = `<Method ID="${index + 1}">${field}</Method>`;
//         return method;
//       });
//   }
// });

import getWebError from "../../utils/errors/getWebError";

const { $ } = window;
/**
 * @name getColumns
 * @description Returns a collection of the column definitions for the columns available on the site.
 * @param {object} options
 * @param {string} [options.webURL=""] A string that contains the relative URL of the site.
 * @param {boolean} [options.async=true] If true, the request is asynchronous.
 * @param {boolean} [options.parse=false] If true, the xml will be parsed into an object
 * @returns {object} Resolves a Promised XML string or object.
 */
const getColumns = ({
  webURL = $().SPServices.defaults.webURL || "",
  async = true,
  parse = false
} = {}) => {
  return new Promise((resolve, reject) => {
    $().SPServices({
      operation: "GetColumns",
      webURL,
      async,
      completefunc: function(xData, status) {
        const responseXML = xData.responseXML;
        // If success
        if (status === "success") {
          // If parse
          if (parse) {
            // Convert response into array
            let array = [...responseXML.getElementsByTagName("Field")].map(
              xml => {
                let field = [...xml.attributes].reduce((object, attribute) => {
                  object[attribute.name] = attribute.value;
                  return object;
                }, {});

                if (field.Type === "Choice") {
                  field.Choices = [...xml.getElementsByTagName("CHOICE")].map(
                    choice => choice.textContent
                  );
                }
                return field;
              }
            );

            // Resolve web
            resolve(array);
          } else {
            resolve(responseXML);
          }
        } else {
          reject(getWebError(xData));
        }
      }
    });
  });
};

export default getColumns;
