import getWebError from "../../utils/errors/getWebError";

const { $ } = window;
/**
 * @name getWeb
 * @description Returns properties of a site (for example, name, description, and theme).
 * @param {object} options
 * @param {string} [options.webURL=""] A string that contains the relative URL of the site.
 * @param {boolean} [options.async=true] If true, the request is asynchronous.
 * @param {boolean} [options.parse=false] If true, the xml will be parsed into an object
 * @returns {object} Resolves a Promised XML string or object.
 */
const getWeb = ({
  webURL = $().SPServices.defaults.webURL || "",
  async = true,
  parse = false
} = {}) => {
  return new Promise((resolve, reject) => {
    $().SPServices({
      operation: "GetWeb",
      webURL,
      async,
      completefunc: function(xData, status) {
        const responseXML = xData.responseXML;
        // If success
        if (status === "success") {
          // If parse
          if (parse) {
            // Convert response into object
            let web = responseXML.getElementsByTagName("Web")[0];
            // If web is found in response XML
            if (web) {
              web = [...web.attributes].reduce((web, attribute) => {
                web[attribute.name] = attribute.value;
                return web;
              }, {});
            } else {
              // Web was not found, set to object literal
              web = {};
            }
            // Resolve web
            resolve(web);
          } else {
            resolve(responseXML);
          }
        } else {
          reject(getWebError(xData));
        }
      }
    });
  });
};

export default getWeb;
