/**
 * @name convertStringToXml
 * @description Converts a string to XML. This is used when an API response has invalid characters
 * @param {String} string The XML string to be parsed
 * @param {Object} [parser] A DOMParser object
 */
const convertStringToXml = (string, parser = null) => {
  // If string is not defined
  if (!string || typeof string !== "string") {
    console.error(
      "Unable to convert string to xml as the string was not defined."
    );
    return "";
  }
  // Create parser (if not already created)
  const domParser = parser ? parser : new DOMParser();

  // Replace illegal characters
  const text = string.replace(/&/g, "&amp;");

  // Parse xml
  const xml = domParser.parseFromString(text, "text/xml");

  return xml;
};

export default convertStringToXml;
