/**
 * @name getPageHtmlFromUrl
 * @param {Object} payload
 * @param {String} [payload.url=document.URL] The page url to retrieve HTML
 * @param {Boolean} [payload.async=true] If true, the request is asynchronous
 * @param {Boolean} [payload.parse=true] If true, the request will be parsed into an XML response instead of plain text.
 * @returns {Node|String} resolves a html node object or text string
 * @example
 * getPageHtmlFromUrl({url: "http://objectpoint/sites/development", async: true, parse: true})
 */
const getPageHtmlFromUrl = ({
  url = document.URL,
  async = true,
  parse = true,
} = {}) => {
  return new Promise((resolve, reject) => {
    // Instantiate xhr object
    let xhr = new XMLHttpRequest();

    // Open request
    xhr.open("GET", url, async);

    // On Ready State change
    xhr.onreadystatechange = function () {
      if (this.readyState === 4) {
        if (this.status === 200) {
          if (parse) {
            resolve(
              new DOMParser().parseFromString(xhr.responseText, "text/html")
            );
          } else {
            resolve(this.responseText);
          }
        } else {
          reject(this.responseText);
        }
      }
    };

    // Send request
    xhr.send();
  });
};

export default getPageHtmlFromUrl;
