/**
 * @name parseEncodedAbsUrl
 * @description Parse item data from FileDirRef
 * @param {string} encodedAbsUrl The Item EncodedAbsUrl string
 * @returns {object} Returns an object contains the ListName, ListUrl, DispFormUrl, EditFormUrl and NewFormUrl
 * @example
 * import parseEncodedAbsUrl from "objectpoint-ui/lib/utils/parseEncodedAbsUrl";
 *
 * // Parse the FileDirRef
 * parseEncodedAbsUrl("http://contoso/sites/development/Lists/Announcements/4_.000");
 *
 * // Returns
 * {
 *  ID: "1",
 *  ListName: "Announcements",
 *  ListUrl: "http://contoso/sites/development/Lists/Announcements",
 *  NewFormUrl: "http://contoso/sites/development/Lists/Announcements/NewForm.aspx",
 *  EditFormUrl: "http://contoso/sites/development/Lists/Announcements/EditForm.aspx?ID=1",
 *  DispFormUrl: "http://contoso/sites/development/Lists/Announcements/DispForm.aspx?ID=1"
 * }
 *
 */
const parseEncodedAbsUrl = (encodedAbsUrl = "") => {
  // Define url object
  let data = {
    ID: "",
    ListUrl: "",
    ListName: "",
    NewFormUrl: "",
    EditFormUrl: "",
    DispFormUrl: "",
  };

  // Check if FileDirRef is valid
  if (!encodedAbsUrl) {
    console.warn(
      "EncodedAbsUrl not passed. Empty strings will be returned for URL values: ",
      encodedAbsUrl
    );
    return data;
  }

  const path = encodedAbsUrl.split("/");
  data.ID = path.pop().split("_")[0];
  data.ListName = path[path.length - 1];
  data.ListUrl = path.join("/");
  data.NewFormUrl = `${data.ListUrl}/NewForm.aspx`;
  data.EditFormUrl = `${data.ListUrl}/EditForm.aspx?ID=${data.ID}`;
  data.DispFormUrl = `${data.ListUrl}/DispForm.aspx?ID=${data.ID}`;

  return data;
};

export default parseEncodedAbsUrl;
