// Utils
import getError from "../errors/getError";

/**
 * @name addFolder
 * @description Adds the specified folder to a library on a site.
 * @required options.listName, option.folder
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {string} options.folder - The folder name. To create sub folders, the name should include the relative path from the library to the folder e.g. myfolder/subfolder.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise Number result.
 */
const addFolder = ({ webURL, listName, async, folder }) =>
  new Promise((resolve, reject) => {
    $().SPServices({
      operation: "UpdateListItems",
      webURL,
      listName,
      async,
      updates: `<Batch OnError="Continue" PreCalc="TRUE" ListVersion="0">
        <Method ID="1" Cmd="New">
          <Field Name="FSObjType">1</Field>
          <Field Name="BaseName">${folder}</Field>
        </Method>
      </Batch>`,
      completefunc: function(xData, status) {
        if (status === "success") {
          // Get the xml
          const xml = xData.responseXML;

          // Create a result object
          let result = {
            ...getError(xml),
            status
          };

          // If a folder already exists
          if (!result.isError) {
            resolve(result);
          } else {
            result.status = "error";
            reject(result);
          }
        } else {
          reject("Unable to create folder");
        }
      }
    });
  });

export default addFolder;
