import Item from "../../classes/lists/Item";
import getListOptions from "../options/getListsOptions";
import updateListItemsError from "../errors/updateListItemsError";

/**
 * @name addListItem
 * @description Adds a list item to a list
 * @required listName
 * @param {Object} options
 * @param {String} options.listName - The list display name.
 * - Required: Yes
 * @param {String} [options.webURL=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {Array} [options.valuepairs=[]] - A multidimensional array of static column names and values.
 * - Required: No
 * - Default: "" (current site)
 * @param {Boolenb} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed with items return
 * - Required: No
 * - Default: false
 * @returns {Promise} Returns a resolved promise.
 */
const addListItem = (options) => {
  return new Promise((resolve, reject) => {
    const { listName, webURL, valuepairs, async, parse } = getListOptions(
      options
    );

    $().SPServices({
      operation: "UpdateListItems",
      webURL,
      async,
      batchCmd: "New",
      listName,
      valuepairs,
      completefunc: function (xData, status) {
        let xml = $(xData.responseXML);
        // If Error is Returned
        if (xml.find("ErrorText").length > 0) {
          reject(updateListItemsError(xData));
          return;
        }
        // If Server Error
        if (status !== "success") {
          reject("Unable to create item");
        } else {
          // If Item Parsing is Requested
          if (parse) {
            xml = xml.SPFilterNode("z:row").toArray()[0];
            if (xml) {
              const item = new Item({ xml });
              resolve(item);
              return;
            }
          } else {
            // If no parsing is required
            resolve(xData.responseXML);
            return;
          }
        }
      },
    });
  });
};

export default addListItem;
