import getListItems from "../../core/lists/getListItems";
import addListItem from "./addListItem";
import getList from "../../core/lists/getList";
import escapeHtml from "../general/escapeHtml";

const copyListItems = ({ source = null, destination = null }) => {
  if (!source || !destination) {
    const error =
      "Unable to copy list items as a source and/or destination list was not defined";
    window.alert(error);
    return error;
  }
  const listName = source;
  new Promise((resolve, reject) => {
    getList({
      listName,
      parse: true,
    }).then((list) => {
      let fields = list.fields
        .filter((field) => {
          if (
            (field.FromBaseType !== "TRUE" &&
              field.Type !== "WorkflowStatus") ||
            field.StaticName === "Title"
          ) {
            return {};
          }
        })
        .map((field) => {
          let { StaticName, DisplayName } = field;
          return {
            StaticName,
            DisplayName,
          };
        });

      resolve({ fields, listName, destination });
    });
  })
    .then((res) => {
      const { fields, listName, destination } = res;
      return new Promise((resolve, reject) => {
        getListItems({
          listName,
          parseItems: true,
        }).then((listItems) => {
          let items = [];
          listItems.forEach((listItem) => {
            let item = {};
            fields.forEach((field) => {
              let key = field.StaticName;
              let value = escapeHtml(listItem[field.StaticName]);
              if (value) item[key] = value;
            });
            items.push(item);
          });

          resolve({ items, destination });
        });
      });
    })
    .then((res) => {
      const { items, destination } = res;
      const listName = destination;
      items.forEach((item) => {
        let valuepairs = [];
        for (const key in item) {
          if (item.hasOwnProperty(key)) {
            valuepairs.push([key, item[key]]);
          }
        }
        addListItem({
          listName,
          valuepairs,
          async: false,
        }).then((item) => {});
      });
      alert("Finished");
    });
};
export default copyListItems;
