import Item from "../../classes/lists/Item";
import getListOptions from "../options/getListsOptions";
import updateListItemsError from "../errors/updateListItemsError";

/**
 * @name deleteListItem
 * @description Deletes a list item in a list
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {number} options.ID - The list item ID number to be deleted.
 * - Required: No
 * - Default: "" (current site)
 * @param {string} [options.webURL=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed with items return
 * - Required: No
 * - Default: false
 * @returns {object} Returns a resolved promise.
 */
const deleteListItem = options => {
  return new Promise((resolve, reject) => {
    const { listName, webURL, ID, async, parse } = getListOptions(options);

    $().SPServices({
      operation: "UpdateListItems",
      webURL,
      async,
      batchCmd: "Delete",
      listName,
      ID,
      completefunc: function(xData, status) {
        let xml = $(xData.responseXML);
        // If Error is Returned
        if (xml.find("ErrorText").length > 0) {
          reject(updateListItemsError(xData));
          return;
        }
        // If Server Error
        if (status !== "success") {
          reject("Unable to create item");
        } else {
          // If Item Parsing is Requested
          if (parse) {
            xml = xml.SPFilterNode("z:row").toArray()[0];
            if (xml) {
              const item = new Item({ xml });
              resolve(item);
              return;
            }
          } else {
            // If no parsing is required
            resolve(xData.responseXML);
            return;
          }
        }
      }
    });
  });
};

export default deleteListItem;
