import getListItems from "../../core/lists/getListItems";
import getListsOptions from "../options/getListsOptions";

/**
 * @name getLastItemID
 * @description Returns the last item ID in a list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * @param {string} [options.webUrl=""] - The web site url
 * @param {boolean} [options.async=true] - Synchronisation Type
 * @param {number} [options.timeout=0] - The timeout between batch requests
 * @returns {Promise} Returns a Promise Number result.
 */
const getLastItemID = (options) => {
  return new Promise((resolve, reject) => {
    const { webURL, listName, async, timeout } = getListsOptions(options);
    // Get List Items
    getListItems({
      webURL,
      listName,
      async,
      CAMLQuery:
        '<Query><Where><IsNotNull><FieldRef Name="ID" /></IsNotNull></Where><OrderBy><FieldRef Name="ID" Ascending="False" /></OrderBy></Query>',
      CAMLViewFields: '<ViewFields><FieldRef Name="ID" /></ViewFields>',
      CAMLRowLimit: 1,
    })
      .then((xml) => {
        let ID = $(xml).SPFilterNode("z:row").attr("ows_ID");
        if (!ID) ID = 0;

        if (timeout) {
          setTimeout(() => resolve(ID), timeout);
        } else {
          resolve(ID);
        }
      })
      .catch((err) => {
        reject(err);
      });
  });
};

export default getLastItemID;
