import getListItems from "../../core/lists/getListItems";
import getListsOptions from "../options/getListsOptions";

/**
 * @name getListItemCount
 * @description Returns the list item count of a queried list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {string} [options.webUrl=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {string} [options.CAMLQuery="<Query></Query>"] - The CAML query as an XML string
 * - Required: No
 * - Default: "<Query></Query>" (Returns all list fields)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise Number result.
 */
const getListItemCount = options => {
  return new Promise((resolve, reject) => {
    const { webURL, listName, async, CAMLQuery } = getListsOptions(options);
    getListItems({
      webURL,
      listName,
      async,
      CAMLQuery,
      CAMLViewFields: '<ViewFields><FieldRef Name="ID" /></ViewFields>'
    })
      .then(xml => {
        const count = parseInt(
          $(xml)
            .SPFilterNode("rs:data")
            .attr("ItemCount")
        );
        resolve(count);
      })
      .catch(err => {
        reject(err);
      });
  });
};

export default getListItemCount;
