import getList from "../../core/lists/getList";
import getListsOptions from "../options/getListsOptions";

/**
 * @name getListViewThreshold
 * @description Get the list view threshold of a list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {string} [options.webUrl=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise Number result.
 */
const getListViewThreshold = options => {
  return new Promise((resolve, reject) => {
    const { WebURL, listName, async } = getListsOptions(options);
    getList({ WebURL, listName, async })
      .then(xml => {
        const listViewThreshold = $(xml)
          .SPFilterNode("List")
          .attr("MaxItemsPerThrottledOperation");
        resolve(listViewThreshold);
      })
      .catch(err => {
        reject(err);
      });
  });
};

export default getListViewThreshold;
