import getListsOptions from "../options/getListsOptions";
import getThrottledListItems from "./getThrottledListItems";

/**
 * @name getThrottledListItemCount
 * @description Returns the list item count of a queried list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {string} [options.webUrl=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {string} [options.CAMLQuery="<Query></Query>"] - The CAML query as an XML string
 * - Required: No
 * - Default: "<Query></Query>" (Returns all list fields)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise Number result.
 */
const getThrottledListItemCount = options => {
  return new Promise((resolve, reject) => {
    const { webURL, listName, async, CAMLQuery } = getListsOptions(options);
    getThrottledListItems({
      webURL,
      listName,
      async,
      CAMLQuery,
      rawXml: true,
      CAMLViewFields: '<ViewFields><FieldRef Name="ID" /></ViewFields>'
    })
      .then(xml => {
        let count = 0;

        $(xml).each(function() {
          count += parseInt(
            $(this)
              .SPFilterNode("rs:data")
              .attr("ItemCount")
          );
        });
        resolve(count);
      })
      .catch(err => {
        reject(err);
      });
  });
};

export default getThrottledListItemCount;
