import getListsOptions from "../options/getListsOptions";
import getThrottledMultiListItems from "./getThrottledMultiListItems";

/**
 * @name getThrottledListItemCount
 * @description Returns the list item count of a queried list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {string} [options.webUrl=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {string} [options.CAMLQuery="<Query></Query>"] - The CAML query as an XML string
 * - Required: No
 * - Default: "<Query></Query>" (Returns all list fields)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise Number result.
 */
const getThrottledListItemCount = options => {
  return new Promise((resolve, reject) => {
    const { webURL, listNames, async, CAMLQuery } = getListsOptions(options);
    getThrottledMultiListItems({
      webURL,
      listNames,
      async,
      CAMLQuery,
      rawXml: true,
      CAMLViewFields: '<ViewFields><FieldRef Name="ID" /></ViewFields>'
    })
      .then(xml => {
        let total = 0;
        $(xml).each(function() {
          let itemCount = $(this)
            .SPFilterNode("rs:data")
            .attr("ItemCount");
          total += parseInt(itemCount);
        });
        resolve(total);
      })
      .catch(err => {
        reject(err);
      });
  });
};

export default getThrottledListItemCount;
