import Item from "../../classes/lists/Item";

/**
 * @name parseListItems
 * @description Returns an array of objects (items) from XML
 * @param {array} options
 * @param {string} options.rows - An array of xml rows
 * - Required: Yes
 * @param {boolean} [options.timeout=10] - The timeout (pause) between iterations when parsing items.
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.viewColumns=null] - Only columns that are selectable in views will be returned
 * - Required: No
 * - Default: null
 * @returns {Promise} Returns a Promise array of objects result.
 */
const parseListItems = (options) => {
  return new Promise((resolve, reject) => {
    const { timeout, CAMLViewFields, allowNullValues, viewColumns } = options;
    const rows = options.rows;
    const items = [];

    if (timeout === 0) {
      rows.forEach((row) => {
        let item = new Item({
          xml: row,
          CAMLViewFields,
          allowNullValues,
          viewColumns,
        });

        items.push(item);
      });
      resolve(items);
      return;
    }

    // If timeout is greater then 0
    (function loop() {
      if (!rows || rows.length === 0) {
        resolve(items);
        return;
      }
      const row = rows.shift();
      let item = new Item({
        xml: row,
        CAMLViewFields,
        allowNullValues,
        viewColumns,
      });
      items.push(item);
      if (timeout) {
        setTimeout(() => {
          loop();
        }, timeout);
      } else {
        loop();
      }
    })();
  });
};

export default parseListItems;
