import getListsError from "../../utils/errors/getListsError";
import getListsOptions from "../../utils/options/getListsOptions";

/**
 * @name updateListItem
 * @description Updates a list item.
 * @required listName, ID
 * @param {Object} options
 * @param {String} options.listName - The list display name.
 * - Required: Yes
 * @param {String} options.ID - The list item ID.
 * - Required: Yes
 * @param {String} [options.webURL=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {Array} [options.valuepairs=[]] - A multidimensional array of static column names and values.
 * - Required: No
 * - Default: "" (current site)
 * @param {Booleab} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a resolved promise.
 */
const updateListItem = options => {
  return new Promise((resolve, reject) => {
    const { webURL, async, listName, ID, valuepairs } = getListsOptions(
      options
    );

    $().SPServices({
      operation: "UpdateListItems",
      webURL,
      async,
      ID,
      listName,
      valuepairs,
      batchCmd: "Update",
      completefunc: function(xData, status) {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject(getListsError(xData));
        }
      }
    });
  });
};

export default updateListItem;
