import getPageHtmlFromUrl from "../general/getPageHtmlFromUrl";
import getList from "../../core/lists/getList";

/**
 * @name getListPermissions
 * @description Get the permissions for a list or library
 * @param {Object} payload
 * @param {String} payload.listName The list display name or GUID
 * @param {String} [payload.listID=null] If the list ID is defined, no web service request is sent to get the list ID.
 * @param {String} [payload.webURL=window.$().SPServices.defaults.webURL] The absolute or relative webURL
 * @returns {Promise<Array>} Resolves an array of objects
 */
const getListPermissions = ({
  webURL = window.$().SPServices.defaults.webURL,
  listName,
  listID = null,
} = {}) =>
  new Promise((resolve, reject) => {
    // Create Promise
    new Promise((resolve, reject) => {
      // If List ID is defined
      if (listID) {
        // Resolve ID
        resolve(listID);
      } else {
        // Get List
        getList({
          webURL,
          listName,
        })
          .then((res) => {
            // Get the list ID
            const ID = res.querySelector("List").getAttribute("ID");

            // Resolve ID
            resolve(ID);
          })
          .catch((error) => {
            reject(error);
          });
      }
    })
      .then((ID) => {
        // Create the page URL
        const url = `${webURL}/_layouts/user.aspx?obj=${ID},list&list=${ID}`;

        // Get the page HTML
        return getPageHtmlFromUrl({ url });
      })
      .then((page) => {
        try {
          // Check if inheriting
          const isInheriting = !!page.querySelector(
            `[id$="StopInherit-Large"]`
          );

          // Get all permissions
          const permissions = [
            ...page.querySelectorAll(
              ".ms-listviewtable tbody tr:not(:first-child)"
            ),
          ].map((tr) => {
            // Create selector based on inheritence
            const selector = isInheriting
              ? "td.ms-vb2"
              : "td:not(:first-child)";

            // Get Table Data
            let data = [...tr.querySelectorAll(selector)].map((el) => {
              return (el.textContent || "").trim();
            });

            const object = {
              name: data[0],
              isUser: data[1] === "User",
              permissions: data[2].split(", ").sort(),
            };

            return object;
          });

          // Resolve array of objects
          resolve(permissions);
        } catch (error) {
          reject(error);
        }
      })
      .catch((error) => {
        reject(error);
      });
  });
export default getListPermissions;
