import getPageHtmlFromUrl from "../general/getPageHtmlFromUrl";
import getList from "../../core/lists/getList";

/**
 * @name getWebPermissions
 * @description Get the permissions for a web
 * @param {Object} payload
 * @param {String} [payload.webURL=window.$().SPServices.defaults.webURL] The absolute or relative webURL
 * @returns {Promise<Array>} Resolves an array of objects
 */
const getWebPermissions = ({
  webURL = window.$().SPServices.defaults.webURL,
} = {}) =>
  new Promise((resolve, reject) => {
    // Create the page URL
    const url = `${webURL}/_layouts/user.aspx`;

    // Get the Page HTML
    getPageHtmlFromUrl({ url })
      .then((page) => {
        try {
          // Get all permissions
          const permissions = [
            ...page.querySelectorAll(
              ".ms-listviewtable tbody tr:not(:first-child)"
            ),
          ].map((tr) => {
            let data = [
              ...tr.querySelectorAll("td:not(:first-child)"),
            ].map((el) => (el.textContent || "").trim());
            return {
              name: data[0],
              isUser: data[1] === "User",
              permissions: data[2].split(", ").sort(),
            };
          });

          // Resolve array of objects
          resolve(permissions);
        } catch (error) {
          reject(error);
        }
      })
      .catch((error) => {
        reject(error);
      });
  });
export default getWebPermissions;
