import getWebPartPagesOptions from "../options/getWebPartPagesOptions";
import getWebPartProperties from "../../core/webPartPages/getWebPartProperties";
import deleteWebPart from "../../core/webPartPages/deleteWebPart";

/**
 * @name deleteAllWebParts
 * @description Deletes all dynamic Web Parts from a Web Part Page.
 * @required pageUrl
 * @param {object} options
 * @param {string} options.pageUrl - A string containing the URL of the Web Part Page.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
const deleteAllWebParts = options => {
  return new Promise((resolve, reject) => {
    const { webURL, pageUrl, async } = getWebPartPagesOptions(options);
    getWebPartProperties({
      pageUrl,
      webURL,
      parse: true,
      async
    })
      .then(webParts => {
        let array = [...webParts];

        (function loop() {
          if (!array || array.length === 0) {
            resolve(`${pageUrl}: Web Parts Deleted`);
            return;
          }

          let webPart = array.shift();

          deleteWebPart({
            pageUrl,
            storageKey: webPart._ID
          })
            .then(() => {
              loop();
            })
            .catch(e => {
              loop();
            });
        })();
      })
      .catch(e => {
        reject(e);
      });
  });
};

export default deleteAllWebParts;
