import getPageHtmlFromUrl from "../general/getPageHtmlFromUrl";
const { $, L_Menu_BaseUrl } = window;

/**
 * @name getSiteCollectionFeatures
 * @description Returns site collection features.
 * @required listName
 * @param {object} options
 * @param {string} [options.webURL= $().SPServices.SPGetCurrentSite()] A string that contains the relative URL of the site.
 * @param {boolean} [options.async=true] If true, the request is asynchronous.
 * @returns {object} Resolves a Promised XML string or object.
 */
const getSiteCollectionFeatures = ({
  webURL = $().SPServices.SPGetCurrentSite(),
  async = true
} = {}) => {
  return new Promise((resolve, reject) => {
    // if webURL is not defined
    if (!webURL) {
      reject(`webURL is not defined`);
    }

    if (webURL.endsWith("/")) {
      webURL = webURL.substring(0, webURL.length - 1);
    }

    // Get url and replace any double slashes with single (incorrect base url can cause double slash)
    let url = webURL + "/_layouts/ManageFeatures.aspx?Scope=Site";

    // Parse page html
    getPageHtmlFromUrl({ url, async })
      .then(html => {
        let array = $(html)
          .find("#FeatureTitleDescription")
          .closest("tbody")
          .find("> tr")
          .toArray()
          .map(el => {
            const $el = $(el);
            let title = $el.find(".ms-standardheader").text();
            let description = $el
              .find(".ms-standardheader")
              .closest("tr")
              .next()
              .text();
            let active = $el.find("input[type='button']").val() !== "Activate";
            return {
              title,
              description,
              active
            };
          })
          .filter(({ title }) => title);

        // Resolve with array
        resolve(array);
      })
      .catch(error => {
        // Reject with error
        reject(error);
      });
  });
};

export default getSiteCollectionFeatures;
