"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

/**
 * @name getPageHtmlFromUrl
 * @param {Object} payload
 * @param {String} [payload.url=document.URL] The page url to retrieve HTML
 * @param {Boolean} [payload.async=true] If true, the request is asynchronous
 * @param {Boolean} [payload.parse=true] If true, the request will be parsed into an XML response instead of plain text.
 * @returns {Node|String} resolves a html node object or text string
 * @example
 * getPageHtmlFromUrl({url: "http://objectpoint/sites/development", async: true, parse: true})
 */
var getPageHtmlFromUrl = function getPageHtmlFromUrl() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$url = _ref.url,
      url = _ref$url === void 0 ? document.URL : _ref$url,
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async,
      _ref$parse = _ref.parse,
      parse = _ref$parse === void 0 ? true : _ref$parse;

  return new Promise(function (resolve, reject) {
    // Instantiate xhr object
    var xhr = new XMLHttpRequest(); // Open request

    xhr.open("GET", url, async); // On Ready State change

    xhr.onreadystatechange = function () {
      if (this.readyState === 4) {
        if (this.status === 200) {
          if (parse) {
            resolve(new DOMParser().parseFromString(xhr.responseText, "text/html"));
          } else {
            resolve(this.responseText);
          }
        } else {
          reject(this.responseText);
        }
      }
    }; // Send request


    xhr.send();
  });
};

var _default = getPageHtmlFromUrl;
exports["default"] = _default;