"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

/**
 * @name parseEncodedAbsUrl
 * @description Parse item data from FileDirRef
 * @param {string} encodedAbsUrl The Item EncodedAbsUrl string
 * @returns {object} Returns an object contains the ListName, ListUrl, DispFormUrl, EditFormUrl and NewFormUrl
 * @example
 * import parseEncodedAbsUrl from "objectpoint-ui/lib/utils/parseEncodedAbsUrl";
 *
 * // Parse the FileDirRef
 * parseEncodedAbsUrl("http://contoso/sites/development/Lists/Announcements/4_.000");
 *
 * // Returns
 * {
 *  ID: "1",
 *  ListName: "Announcements",
 *  ListUrl: "http://contoso/sites/development/Lists/Announcements",
 *  NewFormUrl: "http://contoso/sites/development/Lists/Announcements/NewForm.aspx",
 *  EditFormUrl: "http://contoso/sites/development/Lists/Announcements/EditForm.aspx?ID=1",
 *  DispFormUrl: "http://contoso/sites/development/Lists/Announcements/DispForm.aspx?ID=1"
 * }
 *
 */
var parseEncodedAbsUrl = function parseEncodedAbsUrl() {
  var encodedAbsUrl = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";
  // Define url object
  var data = {
    ID: "",
    ListUrl: "",
    ListName: "",
    NewFormUrl: "",
    EditFormUrl: "",
    DispFormUrl: ""
  }; // Check if FileDirRef is valid

  if (!encodedAbsUrl) {
    console.warn("EncodedAbsUrl not passed. Empty strings will be returned for URL values: ", encodedAbsUrl);
    return data;
  }

  var path = encodedAbsUrl.split("/");
  data.ID = path.pop().split("_")[0];
  data.ListName = path[path.length - 1];
  data.ListUrl = path.join("/");
  data.NewFormUrl = "".concat(data.ListUrl, "/NewForm.aspx");
  data.EditFormUrl = "".concat(data.ListUrl, "/EditForm.aspx?ID=").concat(data.ID);
  data.DispFormUrl = "".concat(data.ListUrl, "/DispForm.aspx?ID=").concat(data.ID);
  return data;
};

var _default = parseEncodedAbsUrl;
exports["default"] = _default;