"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

/**
 * @name parseFileDirRef
 * @description Parse item data from FileDirRef
 * @param {String} FileDirRef The Item File Dir Ref
 * @returns {Object} Returns an object contains the ListName, ListUrl, DispFormUrl, EditFormUrl and NewFormUrl
 * @example
 * import parseFileDirRef from "objectpoint-ui/lib/utils/parseFileDirRef";
 *
 * // Parse the FileDirRef
 * parseFileDirRef("1;#sites/development/Lists/Announcements");
 *
 * // Returns
 * {
 *  ID: "1",
 *  ListName: "Announcements",
 *  ListUrl: "/sites/development/Lists/Announcements",
 *  NewFormUrl: "/sites/development/Lists/Announcements/NewForm.aspx",
 *  EditFormUrl: "/sites/development/Lists/Announcements/EditForm.aspx?ID=1",
 *  DispFormUrl: "/sites/development/Lists/Announcements/DispForm.aspx?ID=1"
 * }
 *
 */
var parseFileDirRef = function parseFileDirRef() {
  var FileDirRef = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";
  // Define url object
  var data = {
    ID: "",
    ListUrl: "",
    ListName: "",
    NewFormUrl: "",
    EditFormUrl: "",
    DispFormUrl: ""
  }; // Check if FileDirRef is valid

  if (!FileDirRef) {
    console.warn("Fil Dir Ref not passed. Empty strings will be returned for URL values: ", FileDirRef);
    return data;
  }

  var path = FileDirRef.split("/");
  data.ID = FileDirRef.split(";#")[0];
  data.ListName = path.pop();
  data.ListUrl = "/".concat(FileDirRef.split("#")[1]);
  data.DispFormUrl = "".concat(data.ListUrl, "/DispForm.aspx?ID=").concat(data.ID);
  data.EditFormUrl = "".concat(data.ListUrl, "/EditForm.aspx?ID=").concat(data.ID);
  data.NewFormUrl = "".concat(data.ListUrl, "/NewForm.aspx");
  return data;
};

var _default = parseFileDirRef;
exports["default"] = _default;