"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getError = _interopRequireDefault(require("../errors/getError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * @name addFolder
 * @description Adds the specified folder to a library on a site.
 * @required options.listName, option.folder
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {string} options.folder - The folder name. To create sub folders, the name should include the relative path from the library to the folder e.g. myfolder/subfolder.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise Number result.
 */
var addFolder = function addFolder(_ref) {
  var webURL = _ref.webURL,
      listName = _ref.listName,
      async = _ref.async,
      folder = _ref.folder;
  return new Promise(function (resolve, reject) {
    $().SPServices({
      operation: "UpdateListItems",
      webURL: webURL,
      listName: listName,
      async: async,
      updates: "<Batch OnError=\"Continue\" PreCalc=\"TRUE\" ListVersion=\"0\">\n        <Method ID=\"1\" Cmd=\"New\">\n          <Field Name=\"FSObjType\">1</Field>\n          <Field Name=\"BaseName\">".concat(folder, "</Field>\n        </Method>\n      </Batch>"),
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          // Get the xml
          var xml = xData.responseXML; // Create a result object

          var result = _objectSpread(_objectSpread({}, (0, _getError["default"])(xml)), {}, {
            status: status
          }); // If a folder already exists


          if (!result.isError) {
            resolve(result);
          } else {
            result.status = "error";
            reject(result);
          }
        } else {
          reject("Unable to create folder");
        }
      }
    });
  });
};

var _default = addFolder;
exports["default"] = _default;