"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _Item = _interopRequireDefault(require("../../classes/lists/Item"));

var _getListsOptions = _interopRequireDefault(require("../options/getListsOptions"));

var _updateListItemsError = _interopRequireDefault(require("../errors/updateListItemsError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name deleteListItem
 * @description Deletes a list item in a list
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {number} options.ID - The list item ID number to be deleted.
 * - Required: No
 * - Default: "" (current site)
 * @param {string} [options.webURL=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parse=false] - XML will be parsed with items return
 * - Required: No
 * - Default: false
 * @returns {object} Returns a resolved promise.
 */
var deleteListItem = function deleteListItem(options) {
  return new Promise(function (resolve, reject) {
    var _getListOptions = (0, _getListsOptions["default"])(options),
        listName = _getListOptions.listName,
        webURL = _getListOptions.webURL,
        ID = _getListOptions.ID,
        async = _getListOptions.async,
        parse = _getListOptions.parse;

    $().SPServices({
      operation: "UpdateListItems",
      webURL: webURL,
      async: async,
      batchCmd: "Delete",
      listName: listName,
      ID: ID,
      completefunc: function completefunc(xData, status) {
        var xml = $(xData.responseXML); // If Error is Returned

        if (xml.find("ErrorText").length > 0) {
          reject((0, _updateListItemsError["default"])(xData));
          return;
        } // If Server Error


        if (status !== "success") {
          reject("Unable to create item");
        } else {
          // If Item Parsing is Requested
          if (parse) {
            xml = xml.SPFilterNode("z:row").toArray()[0];

            if (xml) {
              var item = new _Item["default"]({
                xml: xml
              });
              resolve(item);
              return;
            }
          } else {
            // If no parsing is required
            resolve(xData.responseXML);
            return;
          }
        }
      }
    });
  });
};

var _default = deleteListItem;
exports["default"] = _default;