"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _spcamljs = _interopRequireDefault(require("spcamljs"));

var _getList = _interopRequireDefault(require("../../core/lists/getList"));

var _getListItems = _interopRequireDefault(require("../../core/lists/getListItems"));

var _getMultiListItems = _interopRequireDefault(require("./getMultiListItems"));

var _getThrottledListItems = _interopRequireDefault(require("./getThrottledListItems"));

var _getThrottledMultiListItems = _interopRequireDefault(require("./getThrottledMultiListItems"));

var _parseEncodedAbsUrl2 = _interopRequireDefault(require("../general/parseEncodedAbsUrl"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * @name getItems
 * @description Get list items with advanced options for multi lists and thottle handling
 * @param {Object} payload The configuration payload object
 * @param {Array} payload.listNames An array of list display names as strings
 * @param {Boolean} [payload.parseFileDirRef] If true, the FileDirRef will be parsed into item properties. This will also include the FileDirRef viewfield.
 * @param {Boolean} [payload.debug=false] If true, batches are logged to the console.
 * @param {Boolean} [payload.throttledColumns=false] If true, queries will handle lookup columns over the threshold
 * @param {Boolean} [payload.throttledItems=true] If false, queries will not handle lists over the list view threshold
 * @param {Function} [payload.parseFunction] A callback function that allows item properties to be created/overriden whilst rows are parsed.
 * @param {boolean} [payload.async=true] - Synchronisation Type
 * @param {Number} [payload.maxBatchSize=null] - The maximum batch size. This will override the automatic batch sizing set by listViewThreshold.
 * @param {Number} [payload.CAMLRowLimit = 0] The maximum number of rows to retreive
 * @param {Number} [payload.timeout = 0] If greater than 0, a timeout (delay) in milliseconds will be used before each web request
 * @param {String} [payload.CAMLQuery="<Query />"] The CAML query as a XML string.
 * @param {String} [payload.CAMLQueryOptions="<QueryOptions></QueryOptions>"] The CAML query options as a XML string.
 * @param {String} [payload.webURL=window.$().SPServices.defaults.webURL] The web site url
 * @param {boolean} [payload.allowLongFieldNames=false] If true, the field names contained with values will not be trimmed to 32 characters.
 * This allows field names that exceed 32 characters to be used.
 * This is a rare use case where 2 or more fields share the exact same name for the first 32 characters. For example
 * 1. ThisIsAExtremelyLongTextFieldNam
 * 2. ThisIsAExtremelyLongTextFieldNam0
 */
var getItems = function getItems() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$CAMLQuery = _ref.CAMLQuery,
      CAMLQuery = _ref$CAMLQuery === void 0 ? "<Query />" : _ref$CAMLQuery,
      _ref$CAMLQueryOptions = _ref.CAMLQueryOptions,
      CAMLQueryOptions = _ref$CAMLQueryOptions === void 0 ? "<QueryOptions></QueryOptions>" : _ref$CAMLQueryOptions,
      _ref$CAMLRowLimit = _ref.CAMLRowLimit,
      CAMLRowLimit = _ref$CAMLRowLimit === void 0 ? 0 : _ref$CAMLRowLimit,
      listNames = _ref.listNames,
      _ref$throttledColumns = _ref.throttledColumns,
      throttledColumns = _ref$throttledColumns === void 0 ? false : _ref$throttledColumns,
      _ref$throttledItems = _ref.throttledItems,
      throttledItems = _ref$throttledItems === void 0 ? true : _ref$throttledItems,
      _ref$viewFields = _ref.viewFields,
      viewFields = _ref$viewFields === void 0 ? [] : _ref$viewFields,
      parseFunction = _ref.parseFunction,
      _ref$parseFileDirRef = _ref.parseFileDirRef,
      parseFileDirRef = _ref$parseFileDirRef === void 0 ? false : _ref$parseFileDirRef,
      _ref$maxBatchSize = _ref.maxBatchSize,
      maxBatchSize = _ref$maxBatchSize === void 0 ? null : _ref$maxBatchSize,
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async,
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? window.$().SPServices.defaults.webURL : _ref$webURL,
      _ref$timeout = _ref.timeout,
      timeout = _ref$timeout === void 0 ? 0 : _ref$timeout,
      _ref$debug = _ref.debug,
      debug = _ref$debug === void 0 ? false : _ref$debug,
      _ref$allowLongFieldNa = _ref.allowLongFieldNames,
      allowLongFieldNames = _ref$allowLongFieldNa === void 0 ? false : _ref$allowLongFieldNa;

  // If listNames are not defined, not an array or an empty array.
  if (!listNames || !Array.isArray(listNames) || listNames.length === 0) {
    // Log error and return empty string
    console.error("You have not provided an array of listNames. Unable to proceed with query. An empty array will be returned");
    return [];
  } // Create an index of list IDs and their corresponding index in the items array


  var indexes = {}; // An array of items that are added to each batch

  var items = [];
  return new Promise(function (resolve) {
    // If parseFileDirRef is required and viewfields does not include the field.
    if (parseFileDirRef) {
      if (!viewFields.includes("FileDirRef")) {
        // Push FileDirRef (Deprecated)
        viewFields.push("FileDirRef");
      }

      if (!viewFields.includes("EncodedAbsUrl")) {
        // Push Encoded URL. This replaces FileDirRef
        viewFields.push("EncodedAbsUrl");
      }
    } // Get fields from list


    getFields({
      webURL: webURL,
      listNames: listNames,
      throttledColumns: throttledColumns,
      async: async
    }).then(function (fields) {
      // Create an array of view field batches
      var viewFieldBatches = fields ? // If the fields object is defined, validate the amount of throttled fields
      createViewFieldBatches(fields, viewFields) : // If throttledColumns are not required, add all viewFields to a single batch.
      [viewFields]; // Create request object

      var request = {
        webURL: webURL,
        CAMLQuery: CAMLQuery,
        CAMLQueryOptions: CAMLQueryOptions,
        CAMLRowLimit: CAMLRowLimit,
        maxBatchSize: maxBatchSize,
        debug: debug,
        async: async
      }; // Create batch counters

      var batchCount = viewFieldBatches.length;
      var viewFieldBatchesIndex = 0; // Loop through all batches

      (function loop() {
        // If all batches have been processed
        if (!viewFieldBatches || viewFieldBatches.length === 0) {
          // Resolve items
          return resolve(items);
        } // Create viewFields array from batch


        var viewFields = viewFieldBatches.shift(); // Update view fields for current batch

        request.CAMLViewFields = new _spcamljs["default"]().ViewFields(viewFields.map(function (field) {
          var staticName = allowLongFieldNames ? field : field.slice(0, 32);
          return staticName;
        })).ToString(); // Send SharePoint Request

        sendRequest(request, listNames).then(function (rows) {
          // Create a timeout/delay if a timeout isn't defined.
          // For large requests, default the timeout to 100ms
          var delay = timeout || viewFields.length >= 40 && rows.length >= 1000 ? 100 : 0;
          setTimeout(function () {
            // Increase index
            viewFieldBatchesIndex += 1; // Parse rows

            parseRows(rows, viewFields, viewFieldBatchesIndex === batchCount, batchCount); // Continue loop

            loop();
          }, delay);
        });
      })();
      /**
       * @name parseRows
       * @description Converts rows into items
       * @param {Array} rows An array of rows as xml
       * @param {Array<String>} fields An array of field names as strings
       * @returns {Array<Object>} Returns an array of objects
       */


      function parseRows(rows, fields, isLastBatch) {
        // Iterate through each row
        rows.forEach(function (row, index) {
          // Create item object from viewFields
          var item = fields.reduce(function (object, field) {
            var staticName = allowLongFieldNames ? field : field.slice(0, 32);
            object[field] = row.getAttribute("ows_".concat(staticName)) || "";
            return object;
          }, {}); // Assign item ID (used for matching)

          item.ID = row.getAttribute("ows_ID"); // Add to indexes

          indexes[item.ID] = indexes[item.ID] || index; // Find matched item

          var matchedItem = items[indexes[item.ID]]; // If matched item

          if (matchedItem && !matchedItem.EncodedAbsUrl) {
            // Get EncodedAbsUrl
            var EncodedAbsUrl = row.getAttribute("ows_EncodedAbsUrl") || ""; // If EncodedAbsUrl is defined

            if (EncodedAbsUrl) {
              // Assign EncodedAbsUrl to matched item
              matchedItem.EncodedAbsUrl = EncodedAbsUrl;
            }
          } // If parseFileDirRef is true


          if (isLastBatch && parseFileDirRef) {
            item = _objectSpread(_objectSpread(_objectSpread({}, items[indexes[item.ID]] || {}), item), (0, _parseEncodedAbsUrl2["default"])(item.EncodedAbsUrl));
          } // If a parseFunction callback is defined


          if (parseFunction) item = parseFunction(item); // Add to array

          items[index] = _objectSpread(_objectSpread({}, items[indexes[item.ID]] || {}), item);
        });
      }
    });
  });
  /**
   * @name sendRequest
   * @description Sends the get items request(s) to SharePoint
   * @param {Object} request The request props.
   * @param {Array} listNames An array of list display names
   * @returns {Promise<Array>} Returns an array of items
   */

  function sendRequest(request, listNames) {
    return new Promise(function (resolve, reject) {
      if (!throttledItems) {
        if (listNames.length > 1) {
          (0, _getMultiListItems["default"])(_objectSpread({
            listNames: listNames,
            timeout: timeout
          }, request)).then(resolve);
        } else {
          (0, _getListItems["default"])(_objectSpread({
            listName: listNames[0]
          }, request)).then(function (responseXML) {
            return resolve(_toConsumableArray(responseXML.querySelectorAll("row")));
          })["catch"](function (error) {
            console.error("Unable to get list items, an empty array has been returned :", error);
            resolve([]);
          });
        }
      } else {
        // Send correct request
        if (listNames.length > 1) {
          (0, _getThrottledMultiListItems["default"])(_objectSpread({
            listNames: listNames,
            timeout: timeout
          }, request)).then(resolve);
        } else {
          // Send web request
          (0, _getThrottledListItems["default"])(_objectSpread({
            listName: listNames[0],
            timeout: timeout
          }, request)).then(resolve)["catch"](reject);
        }
      }
    });
  }
};
/**
 * @name getFields
 * @param {Object} payload
 * @param {Array} payload.listNames An array of list display names
 * @param {String} payload.webURL The web URL
 * @param {Boolean} payload.throttledColumns If false, list fields will be resolved as null
 * @param {boolean} [payload.async=true] - Synchronisation Type
 * @returns {Object|Null} Returns an object of field types or null if columns are not throttled
 */


function getFields(_ref2) {
  var listNames = _ref2.listNames,
      webURL = _ref2.webURL,
      throttledColumns = _ref2.throttledColumns,
      _ref2$async = _ref2.async,
      async = _ref2$async === void 0 ? true : _ref2$async;
  // Create promise
  return new Promise(function (resolve) {
    // If columns aren't throttled, resolve fields as null
    if (!throttledColumns) return resolve(null); // Clone the listNames

    var lists = _toConsumableArray(listNames); // Create an object literal to store future field data types


    var fields = {}; // Iterate through all listNames

    (function loop() {
      // If the lists are null or an empty array
      if (!lists || lists.length === 0) {
        // Resolve the fields object
        return resolve(fields);
      } // Get the listName from the lists array


      var listName = lists.shift(); // Get list data from SharePoint

      (0, _getList["default"])({
        webURL: webURL,
        listName: listName,
        async: async
      }).then(function (res) {
        // Parse list fields and add to the fields object
        _toConsumableArray(res.querySelectorAll("Field")).forEach(function (field) {
          return fields[field.getAttribute("StaticName")] = field.getAttribute("Type") || "";
        }); // Loop to next list


        loop();
      });
    })();
  });
}
/**
 * @name createViewFieldBatches
 * @description Creates batches of viewFields to ensure thresholds are not exceeded
 * @param {Object} fields An object of field types
 * @param {Array} viewFields An array of list display names as strings
 * @returns {Array} Returns a multi-dimensional array of viewfield batches.
 */


function createViewFieldBatches(fields, viewFields) {
  // Array to store fields
  var array = [[]]; // Throttled field counter

  var throttledCount = 0; // Iterate through all view fields to build array

  viewFields.forEach(function (field) {
    // Check if field is throttled
    var isThrottled = fields[field] && ["User", "UserMulti", "Calculated", "Lookup", "WorkflowStatus"].includes(fields[field]); // If not throttled

    if (!isThrottled) {
      // Push field to first batch
      array[0].push(field);
    } else {
      // Increase throttled counter
      throttledCount += 1; // If less than 8 throttled fields have been included in viewFields

      if (throttledCount <= 8) {
        // Push field to first batch
        array[0].push(field);
      } else {
        // If the throttled array exceeds 7, push a new arrya
        if (array[array.length - 1].length >= 8) {
          array.push([]);
        } // Push to throttled array


        array[array.length - 1].push(field);
      }
    }
  }); // Return the array of view fields

  return array;
}

var _default = getItems;
exports["default"] = _default;