"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getListItems = _interopRequireDefault(require("../../core/lists/getListItems"));

var _getListsOptions2 = _interopRequireDefault(require("../options/getListsOptions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name getLastItemID
 * @description Returns the last item ID in a list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * @param {string} [options.webUrl=""] - The web site url
 * @param {boolean} [options.async=true] - Synchronisation Type
 * @param {number} [options.timeout=0] - The timeout between batch requests
 * @returns {Promise} Returns a Promise Number result.
 */
var getLastItemID = function getLastItemID(options) {
  return new Promise(function (resolve, reject) {
    var _getListsOptions = (0, _getListsOptions2["default"])(options),
        webURL = _getListsOptions.webURL,
        listName = _getListsOptions.listName,
        async = _getListsOptions.async,
        timeout = _getListsOptions.timeout; // Get List Items


    (0, _getListItems["default"])({
      webURL: webURL,
      listName: listName,
      async: async,
      CAMLQuery: '<Query><Where><IsNotNull><FieldRef Name="ID" /></IsNotNull></Where><OrderBy><FieldRef Name="ID" Ascending="False" /></OrderBy></Query>',
      CAMLViewFields: '<ViewFields><FieldRef Name="ID" /></ViewFields>',
      CAMLRowLimit: 1
    }).then(function (xml) {
      var ID = $(xml).SPFilterNode("z:row").attr("ows_ID");
      if (!ID) ID = 0;

      if (timeout) {
        setTimeout(function () {
          return resolve(ID);
        }, timeout);
      } else {
        resolve(ID);
      }
    })["catch"](function (err) {
      reject(err);
    });
  });
};

var _default = getLastItemID;
exports["default"] = _default;