"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getList = _interopRequireDefault(require("../../core/lists/getList"));

var _getListsOptions2 = _interopRequireDefault(require("../options/getListsOptions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name getListViewThreshold
 * @description Get the list view threshold of a list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {string} [options.webUrl=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise Number result.
 */
var getListViewThreshold = function getListViewThreshold(options) {
  return new Promise(function (resolve, reject) {
    var _getListsOptions = (0, _getListsOptions2["default"])(options),
        WebURL = _getListsOptions.WebURL,
        listName = _getListsOptions.listName,
        async = _getListsOptions.async;

    (0, _getList["default"])({
      WebURL: WebURL,
      listName: listName,
      async: async
    }).then(function (xml) {
      var listViewThreshold = $(xml).SPFilterNode("List").attr("MaxItemsPerThrottledOperation");
      resolve(listViewThreshold);
    })["catch"](function (err) {
      reject(err);
    });
  });
};

var _default = getListViewThreshold;
exports["default"] = _default;