"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getListsOptions2 = _interopRequireDefault(require("../options/getListsOptions"));

var _getMultiListItems = _interopRequireDefault(require("./getMultiListItems"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name getMultiListItemCount
 * @description Returns the list item count of a queried list.
 * @required listName
 * @param {object} options
 * @param {array} options.listNames - The list display names.
 * - Required: Yes
 * @param {string} [options.webUrl=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {string} [options.CAMLQuery="<Query></Query>"] - The CAML query as an XML string
 * - Required: No
 * - Default: "<Query></Query>" (Returns all list fields)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise Number result.
 */
var getMultiListItemCount = function getMultiListItemCount(options) {
  return new Promise(function (resolve, reject) {
    var _getListsOptions = (0, _getListsOptions2["default"])(options),
        webURL = _getListsOptions.webURL,
        listNames = _getListsOptions.listNames,
        async = _getListsOptions.async,
        CAMLQuery = _getListsOptions.CAMLQuery;

    (0, _getMultiListItems["default"])({
      webURL: webURL,
      listNames: listNames,
      async: async,
      CAMLQuery: CAMLQuery,
      rawXml: true,
      CAMLViewFields: '<ViewFields><FieldRef Name="ID" /></ViewFields>'
    }).then(function (xml) {
      var total = 0;
      $(xml).each(function () {
        var itemCount = $(this).SPFilterNode("rs:data").attr("ItemCount");
        total += parseInt(itemCount);
      });
      resolve(total);
    })["catch"](function (err) {
      reject(err);
    });
  });
};

var _default = getMultiListItemCount;
exports["default"] = _default;