"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getListItems = _interopRequireDefault(require("../../core/lists/getListItems"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @name getMultiListItems
 * @description Returns information about items in multiple list based on the same specified query per list.
 * @required listNames
 * @param {Object} options
 * @param {Array} options.listNames - An array of list display names.
 * @param {String} [options.webURL=""] - The web site url
 * @param {String} [options.CAMLViewFields="<ViewFields Properties='True' />"] - The view fields as an XML string
 * @param {String} [options.CAMLQuery="<Query></Query>"] - The CAML query as an XML string
 * @param {String} [options.CAMLQueryOptions="<QueryOptions></QueryOptions>"] - Additional query options as an XML string.
 * @param {Boolean} [payload.debug=false] If true, batches are logged to the console.
 * @param {Number} [options.CAMLRowLimit=0] - The number of rows to retrieve
 * @param {Number} [options.timeout=10] - The timeout (pause) between iterations when parsing items.
 * @param {Boolean} [options.async=true] - Synchronisation Type
 * @param {Boolean} [options.parseItems=false] - XML will be parsed with items return
 * @param {Boolean} [options.rawXml=false] - XML will not be filtered to rows and returned with full response.
 * @returns {Promise} Returns a Promise XML result.
 * @example - // Query list on same site
 * getListItems({
 *    listNames: ["Announcements", "Tasks"],
 * });
 * @example - // Query list on another site
 * getListItems({
 *  listNames: ["Announcements", "Tasks"],
 *  webURL: "http://objectpoint.com/sites/defence"
 * });
 * @example - // Advanced query
 * getListItems({
 *  listNames: ["Announcements"],
 *  webURL: "http://objectpoint.com/sites/defence",
 *  CAMLQuery: '<Query><Where><Eq><FieldRef Name="FirstName" /><Value Type="Text">Mapero</Value></Eq></Where></Query>',
 *  CAMLViewFields: '<ViewFields><FieldRef Name="Title" /></ViewFields>'
 *  parseItems: true
 * });
 */
var getMultiListItems = function getMultiListItems(options) {
  return new Promise(function (resolve) {
    // Ensure options.listNames is an array
    if (options.listNames && !Array.isArray(options.listNames)) options.listNames = [options.listNames]; // Store XML rows

    var rows = []; // Create Lists Array (used to iterate through each list)

    var lists = _toConsumableArray(options.listNames); // Remove options.listNames


    delete options.listNames; // Begin Iterating Through Each List

    (function loop() {
      // If all lists have been requested. End loop and resolve.
      if (!lists || lists.length === 0) {
        var _ref;

        // Convert Multi Dimensional Array to 1 Dimension Array and Resolve;
        resolve((_ref = []).concat.apply(_ref, rows));
        return;
      } // Get List Names from List Names Array


      options.listName = lists.shift(); // Get List Items for List

      (0, _getListItems["default"])(options).then(function (xml) {
        // Push XML response to rows constant
        if (options.parseItems) {
          rows.push(xml);
        } else {
          // If raw xml is request. Do not split filter rows.
          if (options.rawXml) {
            rows.push(xml);
          } else {
            // Else, push filtered rows
            rows.push($(xml).SPFilterNode("z:row").toArray());
          }
        } // Loop to next list


        loop();
      })["catch"](function (error) {
        console.error("Unable to get list items, an empty array has been returned:", error);
        loop();
      });
    })();
  });
};

var _default = getMultiListItems;
exports["default"] = _default;