"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getListsOptions2 = _interopRequireDefault(require("../options/getListsOptions"));

var _getThrottledListItems = _interopRequireDefault(require("./getThrottledListItems"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name getThrottledListItemCount
 * @description Returns the list item count of a queried list.
 * @required listName
 * @param {object} options
 * @param {string} options.listName - The list display name.
 * - Required: Yes
 * @param {string} [options.webUrl=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {string} [options.CAMLQuery="<Query></Query>"] - The CAML query as an XML string
 * - Required: No
 * - Default: "<Query></Query>" (Returns all list fields)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise Number result.
 */
var getThrottledListItemCount = function getThrottledListItemCount(options) {
  return new Promise(function (resolve, reject) {
    var _getListsOptions = (0, _getListsOptions2["default"])(options),
        webURL = _getListsOptions.webURL,
        listName = _getListsOptions.listName,
        async = _getListsOptions.async,
        CAMLQuery = _getListsOptions.CAMLQuery;

    (0, _getThrottledListItems["default"])({
      webURL: webURL,
      listName: listName,
      async: async,
      CAMLQuery: CAMLQuery,
      rawXml: true,
      CAMLViewFields: '<ViewFields><FieldRef Name="ID" /></ViewFields>'
    }).then(function (xml) {
      var count = 0;
      $(xml).each(function () {
        count += parseInt($(this).SPFilterNode("rs:data").attr("ItemCount"));
      });
      resolve(count);
    })["catch"](function (err) {
      reject(err);
    });
  });
};

var _default = getThrottledListItemCount;
exports["default"] = _default;