"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getLastItemID = _interopRequireDefault(require("./getLastItemID"));

var _getListItems = _interopRequireDefault(require("../../core/lists/getListItems"));

var _parseListItems = _interopRequireDefault(require("./parseListItems"));

var _getListsOptions2 = _interopRequireDefault(require("../options/getListsOptions"));

var _listViewThreshold = _interopRequireDefault(require("../../constants/lists/listViewThreshold"));

var _spcamljs = _interopRequireDefault(require("spcamljs"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var buildQuery = function buildQuery(fromID, toID, query) {
  if (query.length > 20) {
    return _spcamljs["default"].FromXml(query).ModifyWhere().AppendAnd().CounterField("ID").GreaterThan(fromID).And().CounterField("ID").LessThanOrEqualTo(toID).ToString();
  } else {
    return "<Query>\n    ".concat(new _spcamljs["default"]().Where().CounterField("ID").GreaterThan(fromID).And().CounterField("ID").LessThanOrEqualTo(toID).ToString(), "\n    </Query>");
  }
};
/**
 * @name batchGetListItems
 * @param {Boolean} [payload.debug=false] If true, batches are logged to the console.
 * @param {*} payload.batches
 * @param {*} payload.listViewThreshold
 * @param {*} payload.listName
 * @param {*} payload.webURL
 * @param {*} payload.query
 * @param {*} payload.CAMLViewFields
 * @param {*} payload.CAMLQueryOptions
 * @param {*} payload.rawXml
 * @param {*} payload.timeout
 */


var batchGetListItems = function batchGetListItems(_ref) {
  var batches = _ref.batches,
      listViewThreshold = _ref.listViewThreshold,
      listName = _ref.listName,
      webURL = _ref.webURL,
      query = _ref.query,
      CAMLViewFields = _ref.CAMLViewFields,
      CAMLQueryOptions = _ref.CAMLQueryOptions,
      rawXml = _ref.rawXml,
      _ref$timeout = _ref.timeout,
      timeout = _ref$timeout === void 0 ? 0 : _ref$timeout,
      _ref$debug = _ref.debug,
      debug = _ref$debug === void 0 ? false : _ref$debug;
  return new Promise(function (resolve, reject) {
    // ID counters
    var fromID = 0;
    var toID = 0 + listViewThreshold; // Response array

    var response = []; // Batch count

    var batchCount = 0; // Self invoking loop

    (function loop() {
      // Create CAMLQuery
      var CAMLQuery = buildQuery(fromID, toID, query);
      var payload = {
        listName: listName,
        webURL: webURL,
        CAMLQuery: CAMLQuery,
        CAMLViewFields: CAMLViewFields,
        CAMLRowLimit: listViewThreshold,
        CAMLQueryOptions: CAMLQueryOptions,
        debug: debug,
        async: false
      }; // If debug is true

      if (debug) {
        console.info("Get Throttled List Items Batch: ".concat(batchCount, " :>> "), _objectSpread({
          fromID: fromID,
          toID: toID
        }, payload));
      } // Increase counter and IDs


      fromID += listViewThreshold;
      toID += listViewThreshold;
      batchCount += 1; // Request items

      (0, _getListItems["default"])(payload).then(function (xml) {
        if (rawXml) {
          response.push(xml);
        } else {
          response.push($(xml).SPFilterNode("z:row").toArray());
        } // If batchCount is less then total


        if (batchCount < batches) {
          // If timeout is defined
          if (timeout) {
            // Set timeout
            setTimeout(function () {
              // Call loop after timeout
              loop();
            }, timeout);
          } else {
            // No timeout is specified, call timeout immediately
            loop();
          }
        } else {
          resolve([].concat.apply([], response));
        }
      })["catch"](function (err) {
        reject(err);
      });
    })();
  });
};
/**
 * @name getListItems
 * @description Returns information about items in the list based on the specified query.
 * @required listName
 * @param {Object} options
 * @param {String} options.listName - The list display name.
 * @param {String} [options.webURL=""] - The web site url
 * @param {Boolean} [options.async=true] - Synchronisation Type
 * @param {String} [options.CAMLViewFields="<ViewFields Properties='True' />"] - The view fields as an XML string
 * @param {String} [options.CAMLQuery="<Query></Query>"] - The CAML query as an XML string
 * @param {String} [options.CAMLQueryOptions="<QueryOptions></QueryOptions>"] - Additional query options as an XML string.
 * @param {Boolean} [options.parseItems=false] - XML will be parsed with items return
 * @param {Number} [options.maxBatchSize=null] - The maximum batch size. This will override the automatic batch sizing set by listViewThreshold.
 * @param {Boolean} [options.rawXml=false] - Returns an array of raw responseXML data.
 * @param {Number} [options.timeout=0] - The timeout between batch requests
 * @param {Boolean} [options.viewColumns=null] - Only columns that are selectable in views will be returned (only if parsing is true)
 * @returns {Promise} Returns a Promise which resolves or array of xml or items.
 */


var getThrottledListItems = function getThrottledListItems(options) {
  return new Promise(function (resolve, reject) {
    var _getListsOptions = (0, _getListsOptions2["default"])(options),
        listName = _getListsOptions.listName,
        webURL = _getListsOptions.webURL,
        async = _getListsOptions.async,
        timeout = _getListsOptions.timeout,
        parseItems = _getListsOptions.parseItems,
        CAMLQuery = _getListsOptions.CAMLQuery,
        CAMLViewFields = _getListsOptions.CAMLViewFields,
        CAMLQueryOptions = _getListsOptions.CAMLQueryOptions,
        maxBatchSize = _getListsOptions.maxBatchSize,
        rawXml = _getListsOptions.rawXml,
        viewColumns = _getListsOptions.viewColumns,
        debug = _getListsOptions.debug;

    var listViewThreshold; // Max Batch Size is truthy and less than list view threshold

    if (maxBatchSize && maxBatchSize < _listViewThreshold["default"]) {
      listViewThreshold = maxBatchSize;
    } else {
      listViewThreshold = _listViewThreshold["default"] - 1;
    }

    var batches = 0; // Get the last item ID

    (0, _getLastItemID["default"])({
      listName: listName,
      webURL: webURL,
      async: async,
      timeout: timeout
    }).then(function (lastItemID) {
      batches = Math.ceil(lastItemID / listViewThreshold);
      return batchGetListItems({
        batches: batches,
        listViewThreshold: listViewThreshold,
        listName: listName,
        webURL: webURL,
        query: CAMLQuery,
        CAMLViewFields: CAMLViewFields,
        CAMLQueryOptions: CAMLQueryOptions,
        rawXml: rawXml,
        timeout: timeout,
        debug: debug
      });
    }).then(function (rows) {
      if (parseItems) {
        (0, _parseListItems["default"])({
          rows: rows,
          CAMLViewFields: CAMLViewFields,
          allowNullValues: false,
          viewColumns: viewColumns
        }).then(function (items) {
          resolve(items);
        });
      } else {
        resolve(rows);
      }
    })["catch"](function (err) {
      reject(err);
    });
  });
};

var _default = getThrottledListItems;
exports["default"] = _default;