"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getThrottledListItems = _interopRequireDefault(require("./getThrottledListItems"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @name getThrottledMultiListItems
 * @description Returns information about items in multiple lists over list view threshold based on the same specified query per list.
 * @required listNames
 * @param {object} options
 * @param {Array} options.listNames - An array of list display names.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {string} [options.CAMLViewFields="<ViewFields Properties='True' />"] - The view fields as an XML string
 * - Required: No
 * - Default: "<ViewFields Properties='True' />" (Returns all list fields)
 * @param {string} [options.CAMLQuery="<Query></Query>"] - The CAML query as an XML string
 * - Required: No
 * - Default: "<Query></Query>" (Returns all list fields)
 * @param {string} [options.CAMLQueryOptions="<QueryOptions></QueryOptions>"] - Additional query options as an XML string.
 * - Required: No
 * - Default: "<QueryOptions></QueryOptions>" (No query options)
 * @param {number} [options.CAMLRowLimit=0] - The number of rows to retrieve
 * - Required: No
 * - Default: 0 (No row limit (excluded list view threshold restraints))
 * @param {number} [options.timeout=0] - The timeout (pause) between batch requests.
 * - Required: No
 * - Default: 10 (ms)
 * @param {boolean} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.parseItems=false] - XML will be parsed with items return
 * - Required: No
 * - Default: false
 * @param {boolean} [options.viewColumns=null] - Only columns that are selectable in views will be returned (only if parsing is true)
 * - Required: No
 * - Default: null
 * @returns {Promise} Returns a Promise XML result.
 */
var getThrottledMultiListItems = function getThrottledMultiListItems(options) {
  return new Promise(function (resolve, reject) {
    // Ensure options.listNames is an array
    if (options.listNames && !Array.isArray(options.listNames)) options.listNames = [options.listNames]; // Store XML rows

    var rows = []; // Create Lists Array (used to iterate through each list)

    var lists = _toConsumableArray(options.listNames); // Remove options.listNames


    delete options.listNames; // Error Counter to count caught errors
    // A rejection will occur if all loops result in an error

    var caughtErrors = 0;
    var allowedErrors = lists.length - 1; // Begin Iterating Through Each List

    (function loop() {
      // If all lists have been requested. End loop and resolve.
      if (!lists || lists.length === 0) {
        var _ref;

        // Convert Multi Dimensional Array to 1 Dimension Array and Resolve;
        resolve((_ref = []).concat.apply(_ref, rows));
        return;
      } // Get List Names from List Names Array


      options.listName = lists.shift(); // Get List Items for List

      (0, _getThrottledListItems["default"])(options).then(function (xml) {
        // Push XML response to rows constant
        if (xml) {
          rows.push(xml);
        } // if timeout is defined


        if (options.timeout) {
          // Call loop after timeout
          setTimeout(function () {
            loop();
          }, options.timeout);
        } else {
          // No timeout defined
          loop();
        }
      })["catch"](function (err) {
        caughtErrors += 1;

        if (caughtErrors >= allowedErrors) {
          return reject(err);
        } // if timeout is defined


        if (options.timeout) {
          // Call loop after timeout
          setTimeout(function () {
            loop();
          }, options.timeout);
        } else {
          // No timeout defined
          loop();
        }
      });
    })();
  });
};

var _default = getThrottledMultiListItems;
exports["default"] = _default;