"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

var viewColumnsArray = ["Attachments", "Author", "Created", "Editor", "ID", "Modified", "Title"];
var listColumnsArray = ["_CopySource", "_EditMenuTableEnd", "_EditMenuTableStart", "_EditMenuTableStart2", "_HasCopyDestinations", "_IsCurrentVersion", "_Level", "_ModerationComments", "_ModerationStatus", "_UIVersion", "_UIVersionString", "Attachments", "Author", "BaseName", "ContentType", "ContentTypeId", "Created_x0020_Date", "Created", "DocIcon", "Edit", "Editor", "EncodedAbsUrl", "File_x0020_Type", "FileDirRef", "FileLeafRef", "FileRef", "FolderChildCount", "FSObjType", "GUID", "HTML_x0020_File_x0020_Type", "ID", "InstanceID", "ItemChildCount", "Last_x0020_Modified", "LinkFilename", "LinkFilename2", "LinkFilenameNoMenu", "LinkTitle", "LinkTitle2", "LinkTitleNoMenu", "MetaInfo", "Modified", "Order", "owshiddenversion", "PermMask", "ProgId", "ScopeId", "SelectTitle", "ServerUrl", "SortBehavior", "SyncClientId", "Title", "UniqueId", "WorkflowInstanceID", "WorkflowVersion"];
/**
 * @name parseList
 * @description Returns an array of objects (items) from XML
 * @param {string} xml An XML string of list data.
 * @param {Array} [columnAttributes=[]] An array of strings for attributes to be returned.
 * @param {Boolean} [customColumns=null] If true, only custom columns are returned.
 * @param {Boolean} [hiddenColumns=null] If true, only hidden columns are returned.
 * @param {Boolean} [readOnlyColumns=null] If true, only read only columns are returned.
 * @param {Boolean} [viewColumns=null] If true, only standard view columns are returned.
 * @returns {Promise} Returns a Promise array of objects result.
 */

var parseList = function parseList() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      xml = _ref.xml,
      _ref$columnAttributes = _ref.columnAttributes,
      columnAttributes = _ref$columnAttributes === void 0 ? [] : _ref$columnAttributes,
      _ref$customColumns = _ref.customColumns,
      customColumns = _ref$customColumns === void 0 ? null : _ref$customColumns,
      _ref$hiddenColumns = _ref.hiddenColumns,
      hiddenColumns = _ref$hiddenColumns === void 0 ? null : _ref$hiddenColumns,
      _ref$readOnlyColumns = _ref.readOnlyColumns,
      readOnlyColumns = _ref$readOnlyColumns === void 0 ? null : _ref$readOnlyColumns,
      _ref$viewColumns = _ref.viewColumns,
      viewColumns = _ref$viewColumns === void 0 ? null : _ref$viewColumns;

  return new Promise(function (resolve, reject) {
    // Create list object
    var list = _toConsumableArray(xml.querySelector("List").attributes).reduce(function (object, _ref2) {
      var nodeName = _ref2.nodeName,
          nodeValue = _ref2.nodeValue;
      object[nodeName] = nodeValue;
      return object;
    }, {}); // Create list fields object


    list.fields = _toConsumableArray(xml.querySelectorAll("Fields > Field")).filter(function (field) {
      var isHidden = field.getAttribute("Hidden") === "TRUE";
      var isReadOnly = field.getAttribute("ReadOnly") === "TRUE";
      var staticName = field.getAttribute("StaticName");
      var isCustom = listColumnsArray.indexOf(staticName) === -1;
      var isViewColumn = viewColumnsArray.indexOf(staticName) === -1; // Validate custom columns

      if (customColumns === true && !isCustom || customColumns === false && isCustom) {
        return false;
      } // Validate Read Only Columns


      if (readOnlyColumns === true && !isReadOnly || readOnlyColumns === false && isReadOnly) {
        return false;
      } // Validate Hidden Columns


      if (hiddenColumns === true && !isHidden || hiddenColumns === false && isHidden) {
        return false;
      } // Validate View Columns


      if (viewColumns === true && isViewColumn && !isCustom || viewColumns === false && !isViewColumn && !isCustom) {
        return false;
      } // Default of return true


      return true;
    }).map(function (node) {
      var field = _toConsumableArray(node.attributes).reduce(function (object, _ref3) {
        var nodeName = _ref3.nodeName,
            nodeValue = _ref3.nodeValue;
        // If columns attributes options are supplied and the attribute is not required, skip
        if (columnAttributes.length > 0 && !columnAttributes.includes(nodeName)) return object; // Assign value to object

        object[nodeName] = nodeValue; // Return object

        return object;
      }, {}); // Set default value


      field.Default = (node.querySelector("Default") || {}).textContent || ""; // Switch by field type

      switch (field.Type) {
        case "Choice":
        case "MultiChoice":
          field.Choices = _toConsumableArray(node.querySelectorAll("CHOICE")).map(function (_ref4) {
            var textContent = _ref4.textContent;
            return textContent;
          });
          break;

        case "Calculated":
          // Formula
          field.Formula = (node.querySelector("Formula") || {}).textContent || ""; // Formula Display Names

          field.FormulaDisplayNames = (node.querySelector("FormulaDisplayNames") || {}).textContent || ""; // Formula Field Refs

          field.FieldRefs = _toConsumableArray(node.querySelectorAll("FieldRef")).map(function (node) {
            return node.getAttribute("Name") || "";
          });
          break;

        default:
          break;
      } // Return field object


      return field;
    }); // Resolve list object (with field data)

    resolve(list);
  });
};

var _default = parseList;
exports["default"] = _default;