"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _Item = _interopRequireDefault(require("../../classes/lists/Item"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name parseListItems
 * @description Returns an array of objects (items) from XML
 * @param {array} options
 * @param {string} options.rows - An array of xml rows
 * - Required: Yes
 * @param {boolean} [options.timeout=10] - The timeout (pause) between iterations when parsing items.
 * - Required: No
 * - Default: true (asynchronous)
 * @param {boolean} [options.viewColumns=null] - Only columns that are selectable in views will be returned
 * - Required: No
 * - Default: null
 * @returns {Promise} Returns a Promise array of objects result.
 */
var parseListItems = function parseListItems(options) {
  return new Promise(function (resolve, reject) {
    var timeout = options.timeout,
        CAMLViewFields = options.CAMLViewFields,
        allowNullValues = options.allowNullValues,
        viewColumns = options.viewColumns;
    var rows = options.rows;
    var items = [];

    if (timeout === 0) {
      rows.forEach(function (row) {
        var item = new _Item["default"]({
          xml: row,
          CAMLViewFields: CAMLViewFields,
          allowNullValues: allowNullValues,
          viewColumns: viewColumns
        });
        items.push(item);
      });
      resolve(items);
      return;
    } // If timeout is greater then 0


    (function loop() {
      if (!rows || rows.length === 0) {
        resolve(items);
        return;
      }

      var row = rows.shift();
      var item = new _Item["default"]({
        xml: row,
        CAMLViewFields: CAMLViewFields,
        allowNullValues: allowNullValues,
        viewColumns: viewColumns
      });
      items.push(item);

      if (timeout) {
        setTimeout(function () {
          loop();
        }, timeout);
      } else {
        loop();
      }
    })();
  });
};

var _default = parseListItems;
exports["default"] = _default;