"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getListsError = _interopRequireDefault(require("../../utils/errors/getListsError"));

var _getListsOptions2 = _interopRequireDefault(require("../../utils/options/getListsOptions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @name updateListItem
 * @description Updates a list item.
 * @required listName, ID
 * @param {Object} options
 * @param {String} options.listName - The list display name.
 * - Required: Yes
 * @param {String} options.ID - The list item ID.
 * - Required: Yes
 * @param {String} [options.webURL=""] - The web site url
 * - Required: No
 * - Default: "" (current site)
 * @param {Array} [options.valuepairs=[]] - A multidimensional array of static column names and values.
 * - Required: No
 * - Default: "" (current site)
 * @param {Booleab} [options.async=true] - Synchronisation Type
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a resolved promise.
 */
var updateListItem = function updateListItem(options) {
  return new Promise(function (resolve, reject) {
    var _getListsOptions = (0, _getListsOptions2["default"])(options),
        webURL = _getListsOptions.webURL,
        async = _getListsOptions.async,
        listName = _getListsOptions.listName,
        ID = _getListsOptions.ID,
        valuepairs = _getListsOptions.valuepairs;

    $().SPServices({
      operation: "UpdateListItems",
      webURL: webURL,
      async: async,
      ID: ID,
      listName: listName,
      valuepairs: valuepairs,
      batchCmd: "Update",
      completefunc: function completefunc(xData, status) {
        if (status === "success") {
          resolve(xData.responseXML);
        } else {
          reject((0, _getListsError["default"])(xData));
        }
      }
    });
  });
};

var _default = updateListItem;
exports["default"] = _default;