"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getPageHtmlFromUrl = _interopRequireDefault(require("../general/getPageHtmlFromUrl"));

var _getList = _interopRequireDefault(require("../../core/lists/getList"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @name getListPermissions
 * @description Get the permissions for a list or library
 * @param {Object} payload
 * @param {String} payload.listName The list display name or GUID
 * @param {String} [payload.listID=null] If the list ID is defined, no web service request is sent to get the list ID.
 * @param {String} [payload.webURL=window.$().SPServices.defaults.webURL] The absolute or relative webURL
 * @returns {Promise<Array>} Resolves an array of objects
 */
var getListPermissions = function getListPermissions() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? window.$().SPServices.defaults.webURL : _ref$webURL,
      listName = _ref.listName,
      _ref$listID = _ref.listID,
      listID = _ref$listID === void 0 ? null : _ref$listID;

  return new Promise(function (resolve, reject) {
    // Create Promise
    new Promise(function (resolve, reject) {
      // If List ID is defined
      if (listID) {
        // Resolve ID
        resolve(listID);
      } else {
        // Get List
        (0, _getList["default"])({
          webURL: webURL,
          listName: listName
        }).then(function (res) {
          // Get the list ID
          var ID = res.querySelector("List").getAttribute("ID"); // Resolve ID

          resolve(ID);
        })["catch"](function (error) {
          reject(error);
        });
      }
    }).then(function (ID) {
      // Create the page URL
      var url = "".concat(webURL, "/_layouts/user.aspx?obj=").concat(ID, ",list&list=").concat(ID); // Get the page HTML

      return (0, _getPageHtmlFromUrl["default"])({
        url: url
      });
    }).then(function (page) {
      try {
        // Check if inheriting
        var isInheriting = !!page.querySelector("[id$=\"StopInherit-Large\"]"); // Get all permissions

        var permissions = _toConsumableArray(page.querySelectorAll(".ms-listviewtable tbody tr:not(:first-child)")).map(function (tr) {
          // Create selector based on inheritence
          var selector = isInheriting ? "td.ms-vb2" : "td:not(:first-child)"; // Get Table Data

          var data = _toConsumableArray(tr.querySelectorAll(selector)).map(function (el) {
            return (el.textContent || "").trim();
          });

          var object = {
            name: data[0],
            isUser: data[1] === "User",
            permissions: data[2].split(", ").sort()
          };
          return object;
        }); // Resolve array of objects


        resolve(permissions);
      } catch (error) {
        reject(error);
      }
    })["catch"](function (error) {
      reject(error);
    });
  });
};

var _default = getListPermissions;
exports["default"] = _default;