"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getWebPartPagesOptions = _interopRequireDefault(require("../options/getWebPartPagesOptions"));

var _getWebPartProperties = _interopRequireDefault(require("../../core/webPartPages/getWebPartProperties"));

var _deleteWebPart = _interopRequireDefault(require("../../core/webPartPages/deleteWebPart"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @name deleteAllWebParts
 * @description Deletes all dynamic Web Parts from a Web Part Page.
 * @required pageUrl
 * @param {object} options
 * @param {string} options.pageUrl - A string containing the URL of the Web Part Page.
 * - Required: Yes
 * @param {string} [options.webURL=""] - The web site url.
 * - Required: No
 * - Default: "" (current site)
 * @param {boolean} [options.async=true] - Synchronisation Type.
 * - Required: No
 * - Default: true (asynchronous)
 * @returns {Promise} Returns a Promise XML result.
 */
var deleteAllWebParts = function deleteAllWebParts(options) {
  return new Promise(function (resolve, reject) {
    var _getWebPartPagesOptio = (0, _getWebPartPagesOptions["default"])(options),
        webURL = _getWebPartPagesOptio.webURL,
        pageUrl = _getWebPartPagesOptio.pageUrl,
        async = _getWebPartPagesOptio.async;

    (0, _getWebPartProperties["default"])({
      pageUrl: pageUrl,
      webURL: webURL,
      parse: true,
      async: async
    }).then(function (webParts) {
      var array = _toConsumableArray(webParts);

      (function loop() {
        if (!array || array.length === 0) {
          resolve("".concat(pageUrl, ": Web Parts Deleted"));
          return;
        }

        var webPart = array.shift();
        (0, _deleteWebPart["default"])({
          pageUrl: pageUrl,
          storageKey: webPart._ID
        }).then(function () {
          loop();
        })["catch"](function (e) {
          loop();
        });
      })();
    })["catch"](function (e) {
      reject(e);
    });
  });
};

var _default = deleteAllWebParts;
exports["default"] = _default;