"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _getPageHtmlFromUrl = _interopRequireDefault(require("../general/getPageHtmlFromUrl"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _window = window,
    $ = _window.$,
    L_Menu_BaseUrl = _window.L_Menu_BaseUrl;
/**
 * @name getSiteCollectionFeatures
 * @description Returns site collection features.
 * @required listName
 * @param {object} options
 * @param {string} [options.webURL= $().SPServices.SPGetCurrentSite()] A string that contains the relative URL of the site.
 * @param {boolean} [options.async=true] If true, the request is asynchronous.
 * @returns {object} Resolves a Promised XML string or object.
 */

var getSiteCollectionFeatures = function getSiteCollectionFeatures() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$webURL = _ref.webURL,
      webURL = _ref$webURL === void 0 ? $().SPServices.SPGetCurrentSite() : _ref$webURL,
      _ref$async = _ref.async,
      async = _ref$async === void 0 ? true : _ref$async;

  return new Promise(function (resolve, reject) {
    // if webURL is not defined
    if (!webURL) {
      reject("webURL is not defined");
    }

    if (webURL.endsWith("/")) {
      webURL = webURL.substring(0, webURL.length - 1);
    } // Get url and replace any double slashes with single (incorrect base url can cause double slash)


    var url = webURL + "/_layouts/ManageFeatures.aspx?Scope=Site"; // Parse page html

    (0, _getPageHtmlFromUrl["default"])({
      url: url,
      async: async
    }).then(function (html) {
      var array = $(html).find("#FeatureTitleDescription").closest("tbody").find("> tr").toArray().map(function (el) {
        var $el = $(el);
        var title = $el.find(".ms-standardheader").text();
        var description = $el.find(".ms-standardheader").closest("tr").next().text();
        var active = $el.find("input[type='button']").val() !== "Activate";
        return {
          title: title,
          description: description,
          active: active
        };
      }).filter(function (_ref2) {
        var title = _ref2.title;
        return title;
      }); // Resolve with array

      resolve(array);
    })["catch"](function (error) {
      // Reject with error
      reject(error);
    });
  });
};

var _default = getSiteCollectionFeatures;
exports["default"] = _default;